@@ -11,23 +11,25 @@ extern Display *dpy;
 extern XIMS current_ims;
 static IMForwardEventStruct *current_forward_eve;
 #endif
+extern gboolean win_kbm_inited;
 
 static char *callback_str_buffer;
 Window focus_win;
 static int timeout_handle;
 
-static void send_fake_key_eve()
+void send_fake_key_eve(KeySym key)
 {
-  KeyCode kc_shift_l = XKeysymToKeycode(dpy, XK_Shift_L);
-  XTestFakeKeyEvent(dpy, kc_shift_l, True, CurrentTime);
-  XTestFakeKeyEvent(dpy, kc_shift_l, False, CurrentTime);
+  KeyCode kc = XKeysymToKeycode(dpy, key);
+  XTestFakeKeyEvent(dpy, kc, True, CurrentTime);
+  XTestFakeKeyEvent(dpy, kc, False, CurrentTime);
 }
 
+
 void send_text_call_back(char *text)
 {
   callback_str_buffer = realloc(callback_str_buffer, strlen(text));
   strcpy(callback_str_buffer, text);
-  send_fake_key_eve();
+  send_fake_key_eve(XK_Shift_L);
 }
 
 
@@ -74,6 +76,8 @@ static void append_str(char **buf, int *bufN, char *text, int len)
 
 void send_text(char *text)
 {
+  char *filter;
+
   if (!text)
     return;
   int len = strlen(text);
@@ -83,38 +87,12 @@ void send_text(char *text)
   char *utf8_gbtext = NULL;
 
   if (gb_output) {
-    u_int rn = 0 , wn = 0;
-    GError *err = NULL;
-    char *big5 = g_convert(text, len, "big5", "UTF-8", &rn, &wn, &err);
-
-    if (err) {
-      dbg("utf8 -> gb  convert error %d %d\n", rn, wn);
-      return;
-    }
-
-    err = NULL;
-    char *gbtext = g_convert(big5, wn, "GB2312", "big5", &rn, &wn, &err);
-    g_free(big5);
-
-    if (err) {
-      dbg("big5 -> gb  convert error %d %d\n", rn, wn);
-      return;
-    }
-
-    err = NULL;
-    utf8_gbtext = g_convert(gbtext, wn, "UTF-8", "GB2312", &rn, &wn, &err);
-    g_free(gbtext);
-
-    if (err) {
-      dbg("gb -> utf8  convert error %d %d\n", rn, wn);
-      return;
-    }
-
+    len = trad2sim(text, len, &utf8_gbtext);
     text = utf8_gbtext;
-    len = wn;
   }
 
-  char *filter = getenv("GCIN_OUTPUT_FILTER");
+direct:
+  filter = getenv("GCIN_OUTPUT_FILTER");
   char filter_text[512];
 
   if (filter) {
@@ -165,7 +143,7 @@ next:
   if (len)
     append_str(&output_buffer, &output_bufferN, text, len);
 
-  g_free(utf8_gbtext);
+  free(utf8_gbtext);
 }
 
 void send_output_buffer_bak()
@@ -185,7 +163,7 @@ void sendkey_b5(char *bchar)
 }
 
 
-void send_ascii(int key)
+void send_ascii(char key)
 {
   sendkey_b5(&key);
 }
@@ -283,6 +261,8 @@ void show_win0();
 void show_win_int();
 void show_win_gtab();
 
+gboolean force_show;
+
 void show_in_win(ClientState *cs)
 {
   if (!cs) {
@@ -392,9 +372,11 @@ void move_IC_in_win(ClientState *cs)
 
    int inpx = cs->spot_location.x;
    int inpy = cs->spot_location.y;
-   XWindowAttributes att;
 
+   XWindowAttributes att;
    XGetWindowAttributes(dpy, inpwin, &att);
+   if (att.override_redirect)
+     return;
 
    if (inpx >= att.width)
      inpx = att.width - 1;
@@ -505,12 +487,12 @@ void toggle_im_enabled(u_int kev_state)
 
 
     if (current_CS->im_state != GCIN_STATE_DISABLED) {
+#if 0
       if (current_CS->in_method== 6 && (kev_state & LockMask) != orig_caps_state &&
           tsin_chinese_english_toggle_key == TSIN_CHINESE_ENGLISH_TOGGLE_KEY_CapsLock) {
-        KeyCode caps = XKeysymToKeycode(dpy, XK_Caps_Lock);
-        XTestFakeKeyEvent(dpy, caps, True, CurrentTime);
-        XTestFakeKeyEvent(dpy, caps, False, CurrentTime);
+        send_fake_key_eve(XK_Caps_Lock);
       }
+#endif
 
       if (current_CS->im_state == GCIN_STATE_ENG_FULL) {
         current_CS->im_state = GCIN_STATE_CHINESE;
@@ -518,8 +500,11 @@ void toggle_im_enabled(u_int kev_state)
         return;
       }
 
-      if (current_CS->in_method == 6)
+      if (current_CS->in_method == 6) {
+#if USE_TSIN
         flush_tsin_buffer();
+#endif
+      }
       else {
         reset_gtab_all();
       }
@@ -577,6 +562,30 @@ void update_active_in_win_geom()
   }
 }
 
+extern GtkWidget *gwin_pho, *gwin0, *gwin_gtab;
+
+gboolean win_is_visible()
+{
+  if (!current_CS)
+    return FALSE;
+  switch (current_CS->in_method) {
+    case 3:
+      return GTK_WIDGET_VISIBLE(gwin_pho);
+#if USE_TSIN
+    case 6:
+      return GTK_WIDGET_VISIBLE(gwin0);
+      break;
+#endif
+    case 10:
+      break;
+    default:
+      if (!gwin_gtab)
+        return FALSE;
+      return GTK_WIDGET_VISIBLE(gwin_gtab);
+  }
+}
+
+
 void disp_gtab_half_full(gboolean hf);
 void tsin_toggle_half_full();
 extern char eng_full_str[];
@@ -610,11 +619,12 @@ void toggle_half_full_char(u_int kev_state)
 //  dbg("half full toggle\n");
 }
 
-void init_gtab(int inmdno, int usenow);
-void init_inter_code(int usenow);
-void init_tab_pp(int usenow);
+void init_gtab(int inmdno);
+void init_inter_code();
+void init_tab_pp();
 void init_tab_pho();
 
+
 void check_CS()
 {
   if (!current_CS) {
@@ -626,10 +636,14 @@ void check_CS()
     temp_CS = *current_CS;
 }
 
+extern int b_show_win_kbm;
 
 void load_tray_icon();
+extern gboolean win_sym_enabled;
 gboolean init_in_method(int in_no)
 {
+  gboolean init_im = !(cur_inmd && (cur_inmd->flag & FLAG_GTAB_SYM_KBM));
+
   if (in_no < 0 || in_no > MAX_GTAB_NUM_KEY)
     return FALSE;
 
@@ -637,18 +651,24 @@ gboolean init_in_method(int in_no)
 
 
   if (current_CS->in_method != in_no) {
-    if (current_CS->in_method == 6)
+    if (!(inmd[in_no].flag & FLAG_GTAB_SYM_KBM)) {
+      if (current_CS->in_method == 6) {
+#if USE_TSIN
       flush_tsin_buffer();
+#endif
+      }
 
-    hide_in_win(current_CS);
+      hide_in_win(current_CS);
+    }
 
+    if (cur_inmd && (cur_inmd->flag & FLAG_GTAB_SYM_KBM))
+      hide_win_kbm();
   }
 
   reset_current_in_win_xy();
 
 //  dbg("switch init_in_method %x %d\n", current_CS, in_no);
 
-
   switch (in_no) {
     case 3:
       current_CS->in_method = in_no;
@@ -657,19 +677,24 @@ gboolean init_in_method(int in_no)
 #if USE_TSIN
     case 6:
       current_CS->in_method = in_no;
-      init_tab_pp(True);
+      init_tab_pp(init_im);
       break;
 #endif
     case 10:
       current_CS->in_method = in_no;
-      init_inter_code(True);
+      init_inter_code();
       break;
     default:
-      init_gtab(in_no, True);
+      init_gtab(in_no);
       if (!inmd[in_no].DefChars)
         return FALSE;
       current_CS->in_method = in_no;
-      show_win_gtab();
+      if (!(inmd[in_no].flag & FLAG_GTAB_SYM_KBM))
+        show_win_gtab();
+      else {
+        win_kbm_inited = 1;
+        show_win_kbm();
+      }
       break;
   }
 
@@ -678,6 +703,10 @@ gboolean init_in_method(int in_no)
 #endif
 
   update_in_win_pos();
+
+  if (win_kbm_inited)
+    update_win_kbm();
+
   return TRUE;
 }
 
@@ -717,6 +746,9 @@ gboolean full_char_proc(KeySym keysym)
 }
 
 
+
+
+
 int feedkey_pho(KeySym xkey, int kbstate);
 int feedkey_pp(KeySym xkey, int state);
 int feedkey_gtab(KeySym key, int kbstate);
@@ -733,16 +765,11 @@ gboolean timeout_raise_window()
   return FALSE;
 }
 
-
-gboolean control_punc(KeySym keysym)
-{
-}
-
 // return TRUE if the key press is processed
 gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
 {
 #if 0
-  dbg_time("key press %x %x", keysym, kev_state);
+  dbg_time("key press %x %x\n", keysym, kev_state);
 #endif
   check_CS();
 
@@ -805,8 +832,22 @@ gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
     }
 
     if (keysym == ',') {
-      create_win_sym();
 
+      if (current_CS->im_state == GCIN_STATE_CHINESE) {
+        if (!win_is_visible())
+          win_sym_enabled=1;
+        else
+          win_sym_enabled^=1;
+      } else
+        win_sym_enabled==0;
+
+      create_win_sym();
+      if (win_sym_enabled) {
+        force_show = TRUE;
+        if (current_CS->im_state == GCIN_STATE_CHINESE)
+          show_in_win(current_CS);
+        force_show = FALSE;
+      }
       return TRUE;
     }
 
@@ -826,6 +867,7 @@ gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
   }
 
 
+  if (!current_CS->b_gcin_protocol) {
   if (((keysym == XK_Control_L || keysym == XK_Control_R)
                    && (kev_state & ShiftMask)) ||
       ((keysym == XK_Shift_L || keysym == XK_Shift_R)
@@ -833,6 +875,7 @@ gboolean ProcessKeyPress(KeySym keysym, u_int kev_state)
      cycle_next_in_method();
      return TRUE;
   }
+  }
 
   if (current_CS->b_raise_window && keysym>=' ' && keysym < 127) {
     if (timeout_handle)
@@ -868,10 +911,27 @@ int feedkey_pp_release(KeySym xkey, int kbstate);
 gboolean ProcessKeyRelease(KeySym keysym, u_int kev_state)
 {
   check_CS();
+#if 0
+  dbg_time("key release %x %x\n", keysym, kev_state);
+#endif
 
   if (current_CS->im_state == GCIN_STATE_DISABLED)
     return FALSE;
 
+#if 1
+  if (current_CS->b_gcin_protocol && (last_keysym == XK_Shift_L ||
+  last_keysym == XK_Shift_R || last_keysym == XK_Control_L || last_keysym == XK_Control_R)) {
+    if (((keysym == XK_Control_L || keysym == XK_Control_R)
+          && (kev_state & ShiftMask)) ||
+        ((keysym == XK_Shift_L || keysym == XK_Shift_R)
+          && (kev_state & ControlMask))) {
+       cycle_next_in_method();
+       return TRUE;
+    }
+  }
+#endif
+
+
 #if USE_TSIN
   switch(current_CS->in_method) {
     case 6:
@@ -912,11 +972,28 @@ int xim_ForwardEventHandler(IMForwardEventStruct *call_data)
 }
 #endif
 
+int skip_window(Window win)
+{
+  XWindowAttributes att;
+  XGetWindowAttributes(dpy, win, &att);
+#if 0
+  dbg("hhh %d %d class:%d all:%x %x\n", att.width, att.height, att.class,
+    att.all_event_masks, att.your_event_mask);
+#endif
+  if (att.override_redirect)
+    return 1;
+
+  return 0;
+}
+
 
 int gcin_FocusIn(ClientState *cs)
 {
   Window win = cs->client_win;
 
+  if (skip_window(win))
+    return;
+
   reset_current_in_win_xy();
 
   if (cs) {
@@ -992,6 +1069,9 @@ int gcin_FocusOut(ClientState *cs)
 {
   gint64 t = current_time();
 
+  if (skip_window(cs->client_win))
+    return;
+
   if (t - last_focus_out_time < 100000) {
     last_focus_out_time = t;
     return;
