@@ -1,5 +1,6 @@
 #define CHANGE_FONT_SIZE "change font size"
 #define GB_OUTPUT_TOGGLE "gb output toggle"
+#define KBM_TOGGLE "kbm toggle"
 
 
 #define GCIN_FONT_SIZE "gcin-font-size"
@@ -30,6 +31,8 @@
 #define GCIN_WIN_COLOR_USE "gcin-win-color-use"
 #define GCIN_CAPSLOCK_LOWER "gcin-capslock-lower"
 #define GCIN_ENG_PHRASE_ENABLED "gcin-eng-phrase-enabled"
+#define GCIN_WIN_SYM_CLICK_CLOSE "gcin-win-sym-click-close"
+#define GCIN_SEL_KEY_COLOR "gcin-sel-key-color"
 
 #define GTAB_DUP_SELECT_BELL "gtab-dup-select-bell"
 #define GTAB_SPACE_AUTO_FIRST "gtab-space-auto-first"
@@ -60,6 +63,7 @@
 #define TSIN_TONE_CHAR_INPUT "tsin-tone-char-input"
 #define TSIN_TAB_PHRASE_END "tsin-tab-phrase-end"
 #define TSIN_TAIL_SELECT_KEY "tsin-tail-select-key"
+#define TSIN_BUFFER_EDITING_MODE "tsin-buffer-editing-mode"
 
 #define PHO_HIDE_ROW2 "pho-hide-row2"
 #define PHO_IN_ROW1 "pho-in-row1"
@@ -79,7 +83,7 @@ extern int gcin_font_size, gcin_font_size_tsin_presel, gcin_font_size_symbol,
            gtab_disp_key_codes, gtab_disp_im_name, gcin_shift_space_eng_full,
            gtab_invalid_key_in, gtab_hide_row2, gtab_in_row1, gtab_capslock_in_eng,
            gcin_capslock_lower, pho_hide_row2, pho_in_row1,
-           gcin_eng_phrase_enabled, gtab_que_wild_card;
+           gcin_eng_phrase_enabled, gtab_que_wild_card, gcin_win_sym_click_close;
 
 extern int default_input_method;
 extern int left_right_button_tips;
@@ -100,13 +104,14 @@ extern int gcin_status_tray;
 extern int tsin_phrase_pre_select;
 extern int tsin_chinese_english_toggle_key;
 extern int tsin_tab_phrase_end, tsin_tail_select_key;
+extern int tsin_buffer_editing_mode;
 
 extern int phonetic_char_dynamic_sequence;
 extern int phonetic_huge_tab, phonetic_speak;
 extern char *phonetic_speak_sel;
 extern int tsin_space_opt, tsin_tone_char_input;
 
-extern char *tsin_phrase_line_color, *tsin_cursor_color, *gcin_font_name;
+extern char *tsin_phrase_line_color, *tsin_cursor_color, *gcin_font_name, *gcin_sel_key_color;
 extern char *gcin_win_color_fg, *gcin_win_color_bg;
 extern int gcin_win_color_use;
 extern int gcin_init_im_enabled;
