@@ -30,6 +30,7 @@ static GtkWidget *check_button_tsin_phrase_pre_select,
                  *check_button_tsin_tone_char_input,
                  *check_button_tsin_tab_phrase_end,
                  *check_button_tsin_tail_select_key,
+		 *check_button_tsin_buffer_editing_mode,
                  *check_button_gcin_capslock_lower,
                  *spinner_tsin_buffer_size;
 
@@ -98,10 +99,10 @@ static gboolean cb_ok( GtkWidget *widget,
 
   save_gcin_conf_int(PHONETIC_CHAR_DYNAMIC_SEQUENCE,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_phonetic_char_dynamic_sequence)));
-
+#if 0
   save_gcin_conf_int(PHO_SIMPLE_WIN,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_pho_simple_win)));
-
+#endif
   save_gcin_conf_int(PHO_HIDE_ROW2,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_pho_hide_row2)));
 
@@ -122,6 +123,9 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(TSIN_TAIL_SELECT_KEY,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_tsin_tail_select_key)));
 
+  save_gcin_conf_int(TSIN_BUFFER_EDITING_MODE,
+       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_tsin_buffer_editing_mode)));
+
   save_gcin_conf_int(GCIN_CAPSLOCK_LOWER,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower)));
 
@@ -205,14 +209,14 @@ static gboolean close_kbm_window( GtkWidget *widget,
   return TRUE;
 }
 
-static GtkWidget *da;
+static GtkWidget *da_phrase_line, *da_cursor, *da_sel_key;
 
 static void cb_save_tsin_phrase_line_color(GtkWidget *widget, gpointer user_data)
 {
   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)user_data;
   gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_selector->colorsel), &tsin_phrase_line_gcolor);
 
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
+  gtk_widget_modify_bg(da_phrase_line, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
 }
 
 
@@ -251,7 +255,7 @@ static void cb_save_tsin_cursor_color(GtkWidget *widget, gpointer user_data)
   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)user_data;
   gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_selector->colorsel), &tsin_cursor_gcolor);
 
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
+  gtk_widget_modify_bg(da_cursor, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
 }
 
 
@@ -284,8 +288,6 @@ static gboolean cb_tsin_cursor_color( GtkWidget *widget,
    return TRUE;
 }
 
-
-
 static GtkWidget *create_kbm_opts()
 {
 
@@ -432,7 +434,7 @@ void create_kbm_window()
   gtk_toggle_button_set_active(
      GTK_TOGGLE_BUTTON(check_button_phonetic_char_dynamic_sequence), phonetic_char_dynamic_sequence);
 
-
+#if 0
   GtkWidget *hbox_pho_simple_win = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_l), hbox_pho_simple_win , TRUE, TRUE, 1);
   GtkWidget *label_pho_simple_win = gtk_label_new(_("詞音/注音精簡視窗"));
@@ -441,7 +443,7 @@ void create_kbm_window()
   gtk_box_pack_start (GTK_BOX (hbox_pho_simple_win), check_button_pho_simple_win, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(
      GTK_TOGGLE_BUTTON(check_button_pho_simple_win), pho_simple_win);
-
+#endif
 
   GtkWidget *hbox_pho_hide_row2 = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_l), hbox_pho_hide_row2 , TRUE, TRUE, 1);
@@ -501,6 +503,14 @@ void create_kbm_window()
   gtk_toggle_button_set_active(
      GTK_TOGGLE_BUTTON(check_button_tsin_tail_select_key), tsin_tail_select_key);
 
+  GtkWidget *hbox_tsin_buffer_editing_mode = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_r), hbox_tsin_buffer_editing_mode , TRUE, TRUE, 1);
+  GtkWidget *label_tsin_buffer_editing_mode = gtk_label_new(_("啟用詞音緩衝區編輯模式"));
+  gtk_box_pack_start (GTK_BOX (hbox_tsin_buffer_editing_mode), label_tsin_buffer_editing_mode, TRUE, TRUE, 0);
+  check_button_tsin_buffer_editing_mode = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_tsin_buffer_editing_mode), check_button_tsin_buffer_editing_mode, FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(
+     GTK_TOGGLE_BUTTON(check_button_tsin_buffer_editing_mode), tsin_buffer_editing_mode);
 
   GtkWidget *hbox_gcin_capslock_lower = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_r), hbox_gcin_capslock_lower , TRUE, TRUE, 1);
@@ -526,11 +536,11 @@ void create_kbm_window()
   GtkWidget *button_tsin_phrase_line_color = gtk_button_new();
   g_signal_connect (G_OBJECT (button_tsin_phrase_line_color), "clicked",
                     G_CALLBACK (cb_tsin_phrase_line_color), G_OBJECT (gcin_kbm_window));
-  da =  gtk_drawing_area_new();
-  gtk_container_add (GTK_CONTAINER (button_tsin_phrase_line_color), da);
+  da_phrase_line =  gtk_drawing_area_new();
+  gtk_container_add (GTK_CONTAINER (button_tsin_phrase_line_color), da_phrase_line);
   gdk_color_parse(tsin_phrase_line_color, &tsin_phrase_line_gcolor);
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
-  gtk_widget_set_size_request(da, 16, 2);
+  gtk_widget_modify_bg(da_phrase_line, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
+  gtk_widget_set_size_request(da_phrase_line, 16, 2);
   gtk_container_add (GTK_CONTAINER (frame_tsin_phrase_line_color), button_tsin_phrase_line_color);
 
   GtkWidget *frame_tsin_cursor_color = gtk_frame_new(_("詞音游標的顏色"));
@@ -539,15 +549,13 @@ void create_kbm_window()
   GtkWidget *button_tsin_cursor_color = gtk_button_new();
   g_signal_connect (G_OBJECT (button_tsin_cursor_color), "clicked",
                     G_CALLBACK (cb_tsin_cursor_color), G_OBJECT (gcin_kbm_window));
-  da =  gtk_drawing_area_new();
-  gtk_container_add (GTK_CONTAINER (button_tsin_cursor_color), da);
+  da_cursor =  gtk_drawing_area_new();
+  gtk_container_add (GTK_CONTAINER (button_tsin_cursor_color), da_cursor);
   gdk_color_parse(tsin_cursor_color, &tsin_cursor_gcolor);
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
-  gtk_widget_set_size_request(da, 16, 2);
+  gtk_widget_modify_bg(da_cursor, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
+  gtk_widget_set_size_request(da_cursor, 16, 2);
   gtk_container_add (GTK_CONTAINER (frame_tsin_cursor_color), button_tsin_cursor_color);
 
-
-
   GtkWidget *hbox_cancel_ok = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_cancel_ok , FALSE, FALSE, 5);
   GtkWidget *button_cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
