@@ -7,6 +7,7 @@
 
 static GdkColor gcin_win_gcolor_fg,
                 gcin_win_gcolor_bg,
+                gcin_sel_key_gcolor,
                 tsin_phrase_line_gcolor,
                 tsin_cursor_gcolor;
 
@@ -24,7 +25,9 @@ static GtkWidget *check_button_gcin_eng_phrase_enabled,
                  *check_button_phonetic_speak,
                  *event_box_win_color_test,
                  *font_sel,
-                 *da,
+                 *da_phrase_line,
+                 *da_cursor,
+                 *da_sel_key,
                  *label_win_color_test,
                  *opt_eng_ch_opts,
                  *opt_im_toggle_keys,
@@ -46,13 +49,13 @@ GtkWidget *main_window;
 
 static GtkWidget *check_button_tsin_phrase_pre_select,
                  *check_button_phonetic_char_dynamic_sequence,
-                 *check_button_pho_simple_win,
                  *check_button_pho_hide_row2,
                  *check_button_pho_in_row1,
                  *check_button_phonetic_huge_tab,
                  *check_button_tsin_tone_char_input,
                  *check_button_tsin_tab_phrase_end,
                  *check_button_tsin_tail_select_key,
+                 *check_button_tsin_buffer_editing_mode,
                  *check_button_gtab_que_wild_card,
                  *check_button_gcin_capslock_lower,
                  *spinner_tsin_buffer_size;
@@ -62,7 +65,6 @@ static GtkWidget *check_button_gtab_dup_select_bell,
                  *check_button_gtab_press_full_auto_send,
                  *check_button_gtab_pre_select,
                  *check_button_gtab_disp_partial_match,
-                 *check_button_gtab_simple_win,
                  *check_button_gtab_disp_key_codes,
                  *check_button_gtab_disp_im_name,
                  *check_button_gtab_invalid_key_in,
@@ -71,7 +73,9 @@ static GtkWidget *check_button_gtab_dup_select_bell,
                  *check_button_gtab_in_row1,
                  *check_button_gtab_capslock_in_eng,
                  *check_button_gtab_vertical_select,
-                 *check_button_gtab_unique_auto_send;
+                 *check_button_gtab_unique_auto_send,
+                 *check_button_gcin_init_im_enabled,
+		 *check_button_gcin_win_sym_click_close;
 
 char *pho_speaker[16];
 int pho_speakerN;
@@ -135,7 +139,7 @@ static void cb_save_tsin_cursor_color(GtkWidget *widget, gpointer user_data)
   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)user_data;
   gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_selector->colorsel), &tsin_cursor_gcolor);
 
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
+  gtk_widget_modify_bg(da_cursor, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
 }
 
 
@@ -443,7 +447,7 @@ add_columns (GtkTreeView *treeview)
   g_object_set_data (G_OBJECT (renderer), "column", (gint *)COLUMN_KEY);
 
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-                                               -1, _("Ctrl-Alt-數字鍵"), renderer,
+                                               -1, _("Ctrl-Alt-鍵"), renderer,
                                                "text", COLUMN_KEY,
                                                "editable", COLUMN_EDITABLE,
                                                NULL);
@@ -489,7 +493,44 @@ static void cb_save_tsin_phrase_line_color(GtkWidget *widget, gpointer user_data
   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)user_data;
   gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_selector->colorsel), &tsin_phrase_line_gcolor);
 
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
+  gtk_widget_modify_bg(da_phrase_line, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
+}
+
+
+static void cb_save_gcin_sel_key_color(GtkWidget *widget, gpointer user_data)
+{
+  GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)user_data;
+  gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(color_selector->colorsel), &gcin_sel_key_gcolor);
+
+  gtk_widget_modify_bg(da_sel_key, GTK_STATE_NORMAL, &gcin_sel_key_gcolor);
+}
+
+
+static gboolean cb_gcin_sel_key_color( GtkWidget *widget, gpointer data)
+{
+   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)gtk_color_selection_dialog_new (_("選擇鍵的顏色"));
+
+   gtk_color_selection_set_current_color(
+           GTK_COLOR_SELECTION(color_selector->colorsel),
+           &gcin_sel_key_gcolor);
+
+   g_signal_connect (GTK_OBJECT (color_selector->ok_button),
+                     "clicked",
+                     G_CALLBACK (cb_save_gcin_sel_key_color),
+                     (gpointer) color_selector);
+#if 1
+   g_signal_connect_swapped (GTK_OBJECT (color_selector->ok_button),
+                             "clicked",
+                             G_CALLBACK (gtk_widget_destroy),
+                             (gpointer) color_selector);
+#endif
+   g_signal_connect_swapped (GTK_OBJECT (color_selector->cancel_button),
+                             "clicked",
+                             G_CALLBACK (gtk_widget_destroy),
+                             (gpointer) color_selector);
+
+   gtk_widget_show((GtkWidget*)color_selector);
+   return TRUE;
 }
 
 
@@ -1003,9 +1044,6 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(PHONETIC_CHAR_DYNAMIC_SEQUENCE,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_phonetic_char_dynamic_sequence)));
 
-  save_gcin_conf_int(PHO_SIMPLE_WIN,
-       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_pho_simple_win)));
-
   save_gcin_conf_int(PHO_HIDE_ROW2,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_pho_hide_row2)));
 
@@ -1026,6 +1064,9 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(TSIN_TAIL_SELECT_KEY,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_tsin_tail_select_key)));
 
+  save_gcin_conf_int(TSIN_BUFFER_EDITING_MODE,
+       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_tsin_buffer_editing_mode)));
+
   save_gcin_conf_int(GCIN_CAPSLOCK_LOWER,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower)));
 
@@ -1123,9 +1164,6 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(GTAB_DISP_PARTIAL_MATCH,
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gtab_disp_partial_match)));
 
-  save_gcin_conf_int(GTAB_SIMPLE_WIN,
-    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gtab_simple_win)));
-
   save_gcin_conf_int(GTAB_DISP_KEY_CODES,
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gtab_disp_key_codes)));
 
@@ -1174,6 +1212,9 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(GCIN_SHIFT_SPACE_ENG_FULL,
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_shift_space_eng_full)));
 
+  save_gcin_conf_int(GCIN_INIT_IM_ENABLED,
+    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_init_im_enabled)));
+
   save_gcin_conf_int(GCIN_ENG_PHRASE_ENABLED,
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_eng_phrase_enabled)));
 
@@ -1185,6 +1226,15 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(PHONETIC_SPEAK,
      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_phonetic_speak)));
 
+  save_gcin_conf_int(GCIN_WIN_SYM_CLICK_CLOSE,
+     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_win_sym_click_close)));
+
+  cstr = gtk_color_selection_palette_to_string(&gcin_sel_key_gcolor, 1);
+  dbg("selkey color %s\n", cstr);
+  save_gcin_conf_str(GCIN_SEL_KEY_COLOR, cstr);
+  g_free(cstr);
+
+
   send_gcin_message(GDK_DISPLAY(), "reload");
 
   exit(0);
@@ -1384,7 +1434,7 @@ static void create_main_win()
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_root_style_use),
        gcin_input_style == InputStyleRoot);
   gtk_box_pack_start (GTK_BOX(hbox_root_style_use), check_button_root_style_use, FALSE, FALSE, 0);
-  GtkWidget *label_root_style_use = gtk_label_new(_("固定視窗位置"));
+  GtkWidget *label_root_style_use = gtk_label_new(_("固定 gcin 視窗位置"));
   gtk_box_pack_start (GTK_BOX(hbox_root_style_use), label_root_style_use, FALSE, FALSE, 0);
 
   GtkAdjustment *adj_root_style_x =
@@ -1448,6 +1498,20 @@ static void create_main_win()
   gdk_color_parse(gcin_win_color_bg, &gcin_win_gcolor_bg);
   gtk_widget_modify_bg(event_box_win_color_test, GTK_STATE_NORMAL, &gcin_win_gcolor_bg);
 
+  GtkWidget *hbox_gcin_sel_key_color = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gcin_sel_key_color , FALSE, FALSE, 0);
+  GtkWidget *label_gcin_sel_key_color = gtk_label_new(_("選擇鍵的顏色"));
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_sel_key_color), label_gcin_sel_key_color , FALSE, FALSE, 0);
+  GtkWidget *button_gcin_sel_key_color = gtk_button_new();
+  g_signal_connect (G_OBJECT (button_gcin_sel_key_color), "clicked",
+                    G_CALLBACK (cb_gcin_sel_key_color), G_OBJECT (main_window));
+  da_sel_key =  gtk_drawing_area_new();
+  gtk_container_add (GTK_CONTAINER (button_gcin_sel_key_color), da_sel_key);
+  gdk_color_parse(gcin_sel_key_color, &gcin_sel_key_gcolor);
+  gtk_widget_modify_bg(da_sel_key, GTK_STATE_NORMAL, &gcin_sel_key_gcolor);
+  gtk_widget_set_size_request(da_sel_key, 16, 2);
+  gtk_container_add (GTK_CONTAINER (hbox_gcin_sel_key_color), button_gcin_sel_key_color);
+
   gtk_box_pack_start (GTK_BOX (vbox), create_im_toggle_keys(), FALSE, FALSE, 0);
 
   GtkWidget *hbox_gcin_remote_client = gtk_hbox_new (FALSE, 0);
@@ -1459,6 +1523,15 @@ static void create_main_win()
   GtkWidget *label_gcin_remote_client = gtk_label_new(_("遠端 client 程式支援 (port 9999-)"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_remote_client), label_gcin_remote_client,  FALSE, FALSE, 0);
 
+  GtkWidget *hbox_gcin_init_im_enabled = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gcin_init_im_enabled, FALSE, FALSE, 0);
+  check_button_gcin_init_im_enabled = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_init_im_enabled),check_button_gcin_init_im_enabled,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_init_im_enabled),
+     gcin_init_im_enabled);
+  GtkWidget *label_gcin_init_im_enabled = gtk_label_new(_("直接進入中文輸入狀態(限非XIM)"));
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_init_im_enabled), label_gcin_init_im_enabled, FALSE, FALSE, 0);
+
   GtkWidget *hbox_gcin_shift_space_eng_full = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gcin_shift_space_eng_full, FALSE, FALSE, 0);
   check_button_gcin_shift_space_eng_full = gtk_check_button_new ();
@@ -1518,17 +1591,26 @@ static void create_main_win()
     }
   }
 
+  GtkWidget *hbox_gcin_win_sym_click_close = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gcin_win_sym_click_close, FALSE, FALSE, 0);
+  check_button_gcin_win_sym_click_close = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_win_sym_click_close),check_button_gcin_win_sym_click_close,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_win_sym_click_close),
+     gcin_win_sym_click_close);
+  GtkWidget *label_gcin_win_sym_click_close = gtk_label_new(_("符號視窗點選後自動關閉"));
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_win_sym_click_close), label_gcin_win_sym_click_close,  FALSE, FALSE, 0);
+
 /* label 3 */
 
   vbox = gtk_vbox_new(FALSE, 0);
   notebooklabel = gtk_label_new(_("注音/詞音"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox, notebooklabel);
 
-  GtkWidget *frame_kbm = gtk_frame_new(_("鍵盤排列方式"));
-  gtk_box_pack_start (GTK_BOX (vbox), frame_kbm, FALSE, FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (frame_kbm), 0);
-
-  gtk_container_add (GTK_CONTAINER (frame_kbm), create_kbm_opts());
+  GtkWidget *hbox_kbm_sw = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_kbm_sw, FALSE, FALSE, 0);
+  GtkWidget *label_kbm_sw = gtk_label_new(_("鍵盤排列方式"));
+  gtk_box_pack_start (GTK_BOX (hbox_kbm_sw), label_kbm_sw, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (hbox_kbm_sw), create_kbm_opts());
 
   GtkWidget *hbox_tsin_sw = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_tsin_sw, FALSE, FALSE, 0);
@@ -1580,15 +1662,6 @@ static void create_main_win()
   GtkWidget *label_phonetic_char_dynamic_sequence = gtk_label_new(_("依使用頻率調整字的順序"));
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_char_dynamic_sequence), label_phonetic_char_dynamic_sequence , FALSE, FALSE, 0);
 
-  GtkWidget *hbox_pho_simple_win = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_pho_simple_win , FALSE, FALSE, 0);
-  check_button_pho_simple_win = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_pho_simple_win), check_button_pho_simple_win, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(
-     GTK_TOGGLE_BUTTON(check_button_pho_simple_win), pho_simple_win);
-  GtkWidget *label_pho_simple_win = gtk_label_new(_("詞音/注音精簡視窗"));
-  gtk_box_pack_start (GTK_BOX (hbox_pho_simple_win), label_pho_simple_win , FALSE, FALSE, 0);
-
   GtkWidget *hbox_pho_hide_row2 = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_pho_hide_row2 , FALSE, FALSE, 0);
   check_button_pho_hide_row2 = gtk_check_button_new ();
@@ -1643,6 +1716,15 @@ static void create_main_win()
   GtkWidget *label_tsin_tail_select_key = gtk_label_new(_("同音字詞選擇按鍵在後"));
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tail_select_key), label_tsin_tail_select_key , FALSE, FALSE, 0);
 
+  GtkWidget *hbox_tsin_buffer_editing_mode = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_tsin_buffer_editing_mode , FALSE, FALSE, 0);
+  check_button_tsin_buffer_editing_mode = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_tsin_buffer_editing_mode), check_button_tsin_buffer_editing_mode, FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(
+     GTK_TOGGLE_BUTTON(check_button_tsin_buffer_editing_mode), tsin_buffer_editing_mode);
+  GtkWidget *label_tsin_buffer_editing_mode = gtk_label_new(_("啟用詞音緩衝區編輯模式"));
+  gtk_box_pack_start (GTK_BOX (hbox_tsin_buffer_editing_mode), label_tsin_buffer_editing_mode, FALSE, FALSE, 0);
+
   GtkWidget *hbox_tsin_buffer_size = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_tsin_buffer_size , FALSE, FALSE, 0);
   GtkWidget *label_tsin_buffer_size = gtk_label_new(_("詞音編輯緩衝區大小"));
@@ -1659,11 +1741,11 @@ static void create_main_win()
   GtkWidget *button_tsin_phrase_line_color = gtk_button_new();
   g_signal_connect (G_OBJECT (button_tsin_phrase_line_color), "clicked",
                     G_CALLBACK (cb_tsin_phrase_line_color), G_OBJECT (main_window));
-  da =  gtk_drawing_area_new();
-  gtk_container_add (GTK_CONTAINER (button_tsin_phrase_line_color), da);
+  da_phrase_line =  gtk_drawing_area_new();
+  gtk_container_add (GTK_CONTAINER (button_tsin_phrase_line_color), da_phrase_line);
   gdk_color_parse(tsin_phrase_line_color, &tsin_phrase_line_gcolor);
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
-  gtk_widget_set_size_request(da, 16, 2);
+  gtk_widget_modify_bg(da_phrase_line, GTK_STATE_NORMAL, &tsin_phrase_line_gcolor);
+  gtk_widget_set_size_request(da_phrase_line, 16, 2);
   gtk_container_add (GTK_CONTAINER (hbox_tsin_phrase_line_color), button_tsin_phrase_line_color);
 
   GtkWidget *hbox_tsin_cursor_color = gtk_hbox_new(FALSE, 0);
@@ -1673,11 +1755,11 @@ static void create_main_win()
   GtkWidget *button_tsin_cursor_color = gtk_button_new();
   g_signal_connect (G_OBJECT (button_tsin_cursor_color), "clicked",
                     G_CALLBACK (cb_tsin_cursor_color), G_OBJECT (main_window));
-  da =  gtk_drawing_area_new();
-  gtk_container_add (GTK_CONTAINER (button_tsin_cursor_color), da);
+  da_cursor =  gtk_drawing_area_new();
+  gtk_container_add (GTK_CONTAINER (button_tsin_cursor_color), da_cursor);
   gdk_color_parse(tsin_cursor_color, &tsin_cursor_gcolor);
-  gtk_widget_modify_bg(da, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
-  gtk_widget_set_size_request(da, 16, 2);
+  gtk_widget_modify_bg(da_cursor, GTK_STATE_NORMAL, &tsin_cursor_gcolor);
+  gtk_widget_set_size_request(da_cursor, 16, 2);
   gtk_container_add (GTK_CONTAINER (hbox_tsin_cursor_color), button_tsin_cursor_color);
 
 /* label 4 */
@@ -1686,26 +1768,6 @@ static void create_main_win()
   notebooklabel = gtk_label_new(_("倉頡/行列"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox, notebooklabel);
 
-  GtkWidget *hbox_gtab_dup_select_bell = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_dup_select_bell, FALSE, FALSE, 0);
-  check_button_gtab_dup_select_bell = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell),check_button_gtab_dup_select_bell,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_dup_select_bell),
-     gtab_dup_select_bell);
-  GtkWidget *label_gtab_sele = gtk_label_new(_("重複字選擇鈴聲"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell), label_gtab_sele,  FALSE, FALSE, 0);
-
-  gtk_box_pack_start (GTK_BOX (vbox), create_spc_opts(), FALSE, FALSE, 0);
-
-  GtkWidget *hbox_gtab_auto_select_by_phrase = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_auto_select_by_phrase, FALSE, FALSE, 0);
-  check_button_gtab_auto_select_by_phrase = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase),check_button_gtab_auto_select_by_phrase,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_auto_select_by_phrase),
-     gtab_auto_select_by_phrase);
-  GtkWidget *label_gtab_auto_select = gtk_label_new(_("由詞庫自動選擇字"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase), label_gtab_auto_select,  FALSE, FALSE, 0);
-
   GtkWidget *hbox_gtab_pre_select = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_pre_select, FALSE, FALSE, 0);
   check_button_gtab_pre_select = gtk_check_button_new ();
@@ -1715,15 +1777,6 @@ static void create_main_win()
   GtkWidget *label_gtab_pre_select = gtk_label_new(_("預覽/預選 字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_pre_select), label_gtab_pre_select,  FALSE, FALSE, 0);
 
-  GtkWidget *hbox_gtab_press_full_auto_send = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_press_full_auto_send, FALSE, FALSE, 0);
-  check_button_gtab_press_full_auto_send = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), check_button_gtab_press_full_auto_send,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_press_full_auto_send),
-     gtab_press_full_auto_send);
-  GtkWidget *label_gtab_gtab_press_full_auto_send = gtk_label_new(_("按滿自動送字"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), label_gtab_gtab_press_full_auto_send,  FALSE, FALSE, 0);
-
   GtkWidget *hbox_gtab_disp_partial_match = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_disp_partial_match, FALSE, FALSE, 0);
   check_button_gtab_disp_partial_match = gtk_check_button_new ();
@@ -1733,15 +1786,6 @@ static void create_main_win()
   GtkWidget *label_gtab_gtab_disp_partial_match = gtk_label_new(_("預選列中顯示部份符合的字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_partial_match), label_gtab_gtab_disp_partial_match,  FALSE, FALSE, 0);
 
-  GtkWidget *hbox_gtab_simple_win = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_simple_win, FALSE, FALSE, 0);
-  check_button_gtab_simple_win = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_simple_win), check_button_gtab_simple_win,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_simple_win),
-     gtab_simple_win);
-  GtkWidget *label_gtab_gtab_simple_win = gtk_label_new(_("較小視窗"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_simple_win), label_gtab_gtab_simple_win,  FALSE, FALSE, 0);
-
   GtkWidget *hbox_gtab_disp_key_codes = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_disp_key_codes, FALSE, FALSE, 0);
   check_button_gtab_disp_key_codes = gtk_check_button_new ();
@@ -1760,24 +1804,6 @@ static void create_main_win()
   GtkWidget *label_gtab_gtab_disp_im_name = gtk_label_new(_("顯示輸入法名稱"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_im_name), label_gtab_gtab_disp_im_name,  FALSE, FALSE, 0);
 
-  GtkWidget *hbox_gtab_invalid_key_in = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_invalid_key_in, FALSE, FALSE, 0);
-  check_button_gtab_invalid_key_in = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), check_button_gtab_invalid_key_in,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_invalid_key_in),
-     gtab_invalid_key_in);
-  GtkWidget *label_gtab_gtab_invalid_key_in = gtk_label_new(_("允許錯誤鍵進入(傳統)"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), label_gtab_gtab_invalid_key_in,  FALSE, FALSE, 0);
-
-  GtkWidget *hbox_gtab_shift_phrase_key = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_shift_phrase_key, FALSE, FALSE, 0);
-  check_button_gtab_shift_phrase_key = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), check_button_gtab_shift_phrase_key,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_shift_phrase_key),
-     gtab_shift_phrase_key);
-  GtkWidget *label_gtab_gtab_shift_phrase_key = gtk_label_new(_("Shift 用來輸入片語(Alt-Shift)"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), label_gtab_gtab_shift_phrase_key,  FALSE, FALSE, 0);
-
   GtkWidget *hbox_gtab_hide_row2 = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_hide_row2, FALSE, FALSE, 0);
   check_button_gtab_hide_row2 = gtk_check_button_new ();
@@ -1796,15 +1822,6 @@ static void create_main_win()
   GtkWidget *label_gtab_in_row1 = gtk_label_new(_("輸入鍵顯示移至第一列"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_in_row1), label_gtab_in_row1,  FALSE, FALSE, 0);
 
-  GtkWidget *hbox_gtab_capslock_in_eng = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_capslock_in_eng, FALSE, FALSE, 0);
-  check_button_gtab_capslock_in_eng = gtk_check_button_new ();
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), check_button_gtab_capslock_in_eng,  FALSE, FALSE, 0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_capslock_in_eng),
-     gtab_capslock_in_eng);
-  GtkWidget *label_gtab_capslock_in_eng = gtk_label_new(_("CapsLock 打開輸入英數"));
-  gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), label_gtab_capslock_in_eng,  FALSE, FALSE, 0);
-
   GtkWidget *hbox_gtab_vertical_select = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_vertical_select, FALSE, FALSE, 0);
   check_button_gtab_vertical_select = gtk_check_button_new ();
@@ -1814,6 +1831,62 @@ static void create_main_win()
   GtkWidget *label_gtab_vertical_select = gtk_label_new(_("垂直選擇"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_vertical_select), label_gtab_vertical_select,  FALSE, FALSE, 0);
 
+  GtkWidget *hbox_gtab_press_full_auto_send = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_press_full_auto_send, FALSE, FALSE, 0);
+  check_button_gtab_press_full_auto_send = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), check_button_gtab_press_full_auto_send,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_press_full_auto_send),
+     gtab_press_full_auto_send);
+  GtkWidget *label_gtab_gtab_press_full_auto_send = gtk_label_new(_("按滿自動送字"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), label_gtab_gtab_press_full_auto_send,  FALSE, FALSE, 0);
+
+  GtkWidget *hbox_gtab_auto_select_by_phrase = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_auto_select_by_phrase, FALSE, FALSE, 0);
+  check_button_gtab_auto_select_by_phrase = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase),check_button_gtab_auto_select_by_phrase,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_auto_select_by_phrase),
+     gtab_auto_select_by_phrase);
+  GtkWidget *label_gtab_auto_select = gtk_label_new(_("由詞庫自動選擇字"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase), label_gtab_auto_select,  FALSE, FALSE, 0);
+
+  GtkWidget *hbox_gtab_dup_select_bell = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_dup_select_bell, FALSE, FALSE, 0);
+  check_button_gtab_dup_select_bell = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell),check_button_gtab_dup_select_bell,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_dup_select_bell),
+     gtab_dup_select_bell);
+  GtkWidget *label_gtab_sele = gtk_label_new(_("重複字選擇鈴聲"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell), label_gtab_sele,  FALSE, FALSE, 0);
+
+  gtk_box_pack_start (GTK_BOX (vbox), create_spc_opts(), FALSE, FALSE, 0);
+
+  GtkWidget *hbox_gtab_invalid_key_in = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_invalid_key_in, FALSE, FALSE, 0);
+  check_button_gtab_invalid_key_in = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), check_button_gtab_invalid_key_in,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_invalid_key_in),
+     gtab_invalid_key_in);
+  GtkWidget *label_gtab_gtab_invalid_key_in = gtk_label_new(_("允許錯誤鍵進入(傳統)"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), label_gtab_gtab_invalid_key_in,  FALSE, FALSE, 0);
+
+  GtkWidget *hbox_gtab_shift_phrase_key = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_shift_phrase_key, FALSE, FALSE, 0);
+  check_button_gtab_shift_phrase_key = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), check_button_gtab_shift_phrase_key,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_shift_phrase_key),
+     gtab_shift_phrase_key);
+  GtkWidget *label_gtab_gtab_shift_phrase_key = gtk_label_new(_("Shift 用來輸入片語(Alt-Shift)"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), label_gtab_gtab_shift_phrase_key,  FALSE, FALSE, 0);
+
+  GtkWidget *hbox_gtab_capslock_in_eng = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_capslock_in_eng, FALSE, FALSE, 0);
+  check_button_gtab_capslock_in_eng = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), check_button_gtab_capslock_in_eng,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_capslock_in_eng),
+     gtab_capslock_in_eng);
+  GtkWidget *label_gtab_capslock_in_eng = gtk_label_new(_("CapsLock 打開輸入英數"));
+  gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), label_gtab_capslock_in_eng,  FALSE, FALSE, 0);
+
   GtkWidget *hbox_gtab_unique_auto_send = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox_gtab_unique_auto_send, FALSE, FALSE, 0);
   check_button_gtab_unique_auto_send = gtk_check_button_new ();
