@@ -16,13 +16,15 @@ DUAL_XIM_ENTRY xim_arr[1];
 DUAL_XIM_ENTRY *pxim_arr;
 #endif
 
+gboolean win_kbm_inited;
+
 char *fullchar[]=
 {"　","！","”","＃","＄","％","＆","’","（","）","＊","＋",
 "，","－","．","／","０","１","２","３","４","５","６","７","８","９","：","；","＜","＝","＞","？",
 "＠","Ａ","Ｂ","Ｃ","Ｄ","Ｅ","Ｆ","Ｇ","Ｈ","Ｉ","Ｊ","Ｋ","Ｌ","Ｍ","Ｎ","Ｏ","Ｐ","Ｑ","Ｒ","Ｓ",
 "Ｔ","Ｕ","Ｖ","Ｗ","Ｘ","Ｙ","Ｚ","〔","＼","〕","︿","ˍ",
 "‘","ａ","ｂ","ｃ","ｄ","ｅ","ｆ","ｇ","ｈ","ｉ","ｊ","ｋ","ｌ","ｍ",
-"ｎ","ｏ","ｐ","ｑ","ｒ","ｓ","ｔ","ｕ","ｖ","ｗ","ｘ","ｙ","ｚ","｛","｜","｝","～"
+"ｎ","ｏ","ｐ","ｑ","ｒ","ｓ","ｔ","ｕ","ｖ","ｗ","ｘ","ｙ","ｚ","｛","｜","｝","∼"
 };
 
 char *half_char_to_full_char(KeySym xkey)
@@ -288,6 +290,8 @@ static void reload_data()
   change_win_pho_style();
   load_tab_pho_file();
   change_tsin_color();
+  if (win_kbm_inited)
+    update_win_kbm();
 }
 
 void change_tsin_font_size();
@@ -323,6 +327,16 @@ void cb_trad_sim_toggle()
 #endif
 }
 void execute_message(char *message);
+int b_show_win_kbm=0;
+void kbm_toggle()
+{
+  win_kbm_inited = 1;
+  b_show_win_kbm^=1;
+  if (b_show_win_kbm)
+    show_win_kbm();
+  else
+    hide_win_kbm();
+}
 
 static GdkFilterReturn my_gdk_filter(GdkXEvent *xevent,
                                      GdkEvent *event,
@@ -356,6 +370,9 @@ static GdkFilterReturn my_gdk_filter(GdkXEvent *xevent,
        if (!strcmp(message, GB_OUTPUT_TOGGLE)) {
          cb_trad_sim_toggle();
        } else
+       if (!strcmp(message, KBM_TOGGLE)) {
+         kbm_toggle();
+       } else
        if (strstr(message, "#gcin_message")) {
          execute_message(message);
        }
@@ -519,6 +536,7 @@ int main(int argc, char **argv)
   }
 #endif
 
+
   gtk_main();
 
   return 0;
