@@ -128,7 +128,7 @@ void get_sys_table_file_name(char *name, char *fname);
 char *half_char_to_full_char(KeySym xkey);
 void send_text(char *text);
 void sendkey_b5(char *bchar);
-void send_ascii(int key);
+void send_ascii(char key);
 void bell();
 void set_label_font_size(GtkWidget *label, int size);
 void send_gcin_message(Display *dpy, char *s);
