@@ -1,6 +1,6 @@
 
 /*
-	Copyright (C) 2006	Edward Liu Taiwan
+	Copyright (C) 2006-2008	Edward Der-Hua Liu, Hsin-Chu, Taiwan
 */
 
 #include <stdio.h>
@@ -169,29 +169,54 @@ int main(int argc, char **argv)
   char *phrbuf = NULL;
   int prbf_cou=0;
 
+  INMD tinmd, *inp = &tinmd, *cur_inmd = &tinmd;
 
-  if (!strcmp(fname, "-v") || !strcmp(fname, "--version")) {
-    dbg("gcin2tab for gcin " GCIN_VERSION "\n");
-    exit(0);
+  if (argc != 4) {
+    dbg("\tgtab-merge for gcin " GCIN_VERSION "\n");
+    p_err("%s input_file.gtab  phrase_file.append   final-output.gtab", argv[0]);
   }
 
-  if (argc != 4)
-    p_err("%s input_file.gtab  phrase_file.append   output.gtab.final", argv[0]);
-
   if ((fr=fopen(argv[1], "r"))==NULL)
       p_err("cannot err open %s", argv[1]);
 
-  gboolean key64;
-  INMD inmd, *inp = &inmd, *cur_inmd = &inmd;
+  gboolean key64=64;
 
   inp->tbl64 = itout64;
   inp->tbl = itout;
 
-
   fread(&th,1, sizeof(th), fr);
+#if NEED_SWAP
+  swap_byte_4(&th.version);
+  swap_byte_4(&th.flag);
+  swap_byte_4(&th.space_style);
+  swap_byte_4(&th.KeyS);
+  swap_byte_4(&th.MaxPress);
+  swap_byte_4(&th.M_DUP_SEL);
+  swap_byte_4(&th.DefC);
+  for(i=0; i <= KeyNum; i++)
+    swap_byte_4(&idx1[i]);
+#endif
   KeyNum = th.KeyS;
   dbg("keys %d\n",KeyNum);
 
+  if (!th.keybits)
+    th.keybits = 6;
+  inp->keybits = th.keybits;
+  dbg("keybits:%d\n", th.keybits);
+
+  if (th.MaxPress*th.keybits > 32) {
+    inp->max_keyN = 64 / th.keybits;
+    key64 = inp->key64 = TRUE;
+    dbg("it's a 64-bit .gtab\n");
+  } else {
+    inp->max_keyN = 32 / th.keybits;
+    key64 = inp->key64 = FALSE;
+  }
+
+  inp->last_k_bitn = (((inp->key64 ? 64:32) / inp->keybits) - 1) * inp->keybits;
+  dbg("inp->key64:%d\n", inp->key64);
+
+
   fread(keymap, 1, th.KeyS, fr);
   fread(kname, CH_SZ, th.KeyS, fr);
   fread(idx1, sizeof(gtab_idx1_t), KeyNum+1, fr);
@@ -200,15 +225,6 @@ int main(int argc, char **argv)
     kno[keymap[i]] = i;
   }
 
-  if (th.MaxPress > 5) {
-    inp->max_keyN = 10;
-    key64 = inp->key64 = TRUE;
-    dbg("it's a 64-bit .gtab\n");
-  } else {
-    inp->max_keyN = 5;
-    key64 = inp->key64 = FALSE;
-  }
-
   for(i=0; i < th.DefC; i++) {
     ITEM it;
     ITEM64 it64;
@@ -269,7 +285,7 @@ int main(int argc, char **argv)
         cmd[i] : mtolower(cmd[i]);
 
       k=kno[key];
-      kk|=(u_int64_t)k << ( LAST_K_bitN - i*6);
+      kk|=(u_int64_t)k << ( LAST_K_bitN - i*cur_inmd->keybits);
     }
 
     if (key64) {
@@ -343,6 +359,8 @@ int main(int argc, char **argv)
   bzero(def1,sizeof(def1));
   bzero(idx1,sizeof(idx1));
 
+  u_int64_t key_mask = KEY_MASK;
+
   for(i=0; i<chno; i++) {
     u_int64_t key = CONVT2(cur_inmd, i);
 #if 0
