@@ -1,5 +1,5 @@
 /*
-	Copyright (C) 2004	 Edward Liu, Hsin-Chu, Taiwan
+	Copyright (C) 2004-2008	Edward Der-Hua Liu, Hsin-Chu, Taiwan
 */
 
 #include <sys/stat.h>
@@ -25,7 +25,7 @@ INMD *cur_inmd;
 static gboolean last_full, more_pg, wild_mode, spc_pressed, invalid_spc;
 static char seltab[MAX_SELKEY][MAX_CIN_PHR];
 static short defselN, exa_match;
-static KeySym inch[MAX_TAB_KEY_NUM64];
+static KeySym inch[MAX_TAB_KEY_NUM64_6];
 static int ci;
 static int last_idx, pg_idx;
 static int wild_page;
@@ -59,7 +59,7 @@ gboolean gtab_has_input()
 {
   int i;
 
-  for(i=0; i < MAX_TAB_KEY_NUM64; i++)
+  for(i=0; i < MAX_TAB_KEY_NUM64_6; i++)
     if (inch[i])
       return TRUE;
 
@@ -164,7 +164,7 @@ void lookup_gtabn(char *ch, char *out)
     int j;
 
     int tlen=0, klen=0;
-    char t[CH_SZ * MAX_TAB_KEY_NUM64 + 1];
+    char t[CH_SZ * 10 + 1];
 
     for(j=Max_tab_key_num1(tinmd) - 1; j>=0; j--) {
 
@@ -327,6 +327,9 @@ static void DispInArea()
 
   for(i=0;i<ci;i++) {
     disp_gtab(i, &cur_inmd->keyname[inch[i] * CH_SZ]);
+//    dbg("inch:%d ", inch[i]);
+//    utf8_putchar(&cur_inmd->keyname[inch[i] * CH_SZ]);
+//    puts("");
   }
 
   for(; i < cur_inmd->MaxPress; i++) {
@@ -347,7 +350,8 @@ time_t file_mtime(char *fname)
   return st.st_mtime;
 }
 
-void init_gtab(int inmdno, int usenow)
+
+void init_gtab(int inmdno)
 {
   FILE *fp;
   char ttt[128],uuu[128];
@@ -427,6 +431,12 @@ void init_gtab(int inmdno, int usenow)
 
   fread(&th,1,sizeof(th),fp);
 
+  if (th.keybits<6 || th.keybits>7)
+    th.keybits = 6;
+
+  inp->keybits = th.keybits;
+  dbg("keybits:%d\n", th.keybits);
+
 #if NEED_SWAP
   swap_byte_4(&th.version);
   swap_byte_4(&th.flag);
@@ -437,30 +447,39 @@ void init_gtab(int inmdno, int usenow)
   swap_byte_4(&th.DefC);
 #endif
 
-  if (th.MaxPress > 5) {
-    inp->max_keyN = 10;
+  if (th.MaxPress*th.keybits > 32) {
+    inp->max_keyN = 64 / th.keybits;
     inp->key64 = TRUE;
     dbg("it's a 64-bit .gtab\n");
   } else {
-    inp->max_keyN = 5;
+    inp->max_keyN = 32 / th.keybits;
   }
 
   free(inp->endkey);
   inp->endkey = strdup(th.endkey);
 
+  if (th.flag & FLAG_GTAB_SYM_KBM)
+    dbg("symbol kbm\n");
+
   fread(ttt, 1, th.KeyS, fp);
   dbg("KeyS %d\n", th.KeyS);
 
+  if (inp->keyname)
+    free(inp->keyname);
+  inp->keyname = tmalloc(char, (th.KeyS + 3) * CH_SZ);
   fread(inp->keyname, CH_SZ, th.KeyS, fp);
-#define WILD_QUES 64
-#define WILD_STAR 65
-  utf8cpy(&inp->keyname[WILD_QUES*CH_SZ], "？");  /* for wild card */
-  utf8cpy(&inp->keyname[WILD_STAR*CH_SZ], "＊");
+  inp->WILD_QUES=th.KeyS+1;
+  inp->WILD_STAR=th.KeyS+2;
+  utf8cpy(&inp->keyname[inp->WILD_QUES*CH_SZ], "？");  /* for wild card */
+  utf8cpy(&inp->keyname[inp->WILD_STAR*CH_SZ], "＊");
+
+  char *keyname = &inp->keyname[1 * CH_SZ];
+
 
   // for boshiamy
   extern u_char *fullchar[];
   gboolean all_full_ascii = TRUE;
-  char keyname_lookup[MAX_GTAB_KEYS];
+  char keyname_lookup[256];
 
   bzero(keyname_lookup, sizeof(keyname_lookup));
   for(i=1; i < th.KeyS; i++) {
@@ -491,9 +510,11 @@ void init_gtab(int inmdno, int usenow)
 
 
   if (all_full_ascii) {
+    dbg("all_full_ascii\n");
+    int mkeys = 1<< th.keybits;
     free(inp->keyname_lookup);
-    inp->keyname_lookup = malloc(sizeof(char) * MAX_GTAB_KEYS);
-    memcpy(inp->keyname_lookup, keyname_lookup, MAX_GTAB_KEYS);
+    inp->keyname_lookup = malloc(sizeof(char) * mkeys);
+    memcpy(inp->keyname_lookup, keyname_lookup, mkeys);
   }
 
   inp->KeyS=th.KeyS;
@@ -506,20 +527,28 @@ void init_gtab(int inmdno, int usenow)
   free(inp->cname);
   inp->cname = strdup(th.cname);
 
-  dbg("MaxPress:%d  M_DUP_SEL:%d\n", th.MaxPress, th.M_DUP_SEL);
+//  dbg("MaxPress:%d  M_DUP_SEL:%d\n", th.MaxPress, th.M_DUP_SEL);
 
   free(inp->keymap);
   inp->keymap = tzmalloc(char, 128);
 
+  if (!(th.flag & FLAG_GTAB_SYM_KBM)) {
+    inp->keymap[(int)'?']=inp->WILD_QUES;
+    if (!strchr(th.selkey, '*'))
+      inp->keymap[(int)'*']=inp->WILD_STAR;
+  }
+
+  free(inp->keycol);
+  inp->keycol=tzmalloc(char, th.KeyS+1);
   for(i=0;i<th.KeyS;i++) {
+    dbg("%c", ttt[i]);
     inp->keymap[(int)ttt[i]]=i;
+//    dbg("%d %d %c\n", i, inp->keymap[(int)ttt[i]], ttt[i]);
     if (!BITON(inp->flag, FLAG_KEEP_KEY_CASE))
       inp->keymap[toupper(ttt[i])]=i;
     inp->keycol[i]=key_col(ttt[i]);
   }
-
-  inp->keymap[(int)'?']=WILD_QUES;
-  inp->keymap[(int)'*']=WILD_STAR;
+  dbg("\n");
 
   free(inp->idx1);
   inp->idx1 = tmalloc(gtab_idx1_t, th.KeyS+1);
@@ -602,12 +631,10 @@ void init_gtab(int inmdno, int usenow)
 
   fclose(fp);
 
-  if (usenow) {
-    cur_inmd=inp;
+  cur_inmd=inp;
 //    reset_inp();
-    set_gtab_input_method_name(inp->cname);
-    DispInArea();
-  }
+  set_gtab_input_method_name(inp->cname);
+  DispInArea();
 
   dbg("key64: %d\n", inp->key64);
 
@@ -616,21 +643,18 @@ void init_gtab(int inmdno, int usenow)
   else
     _gtab_space_auto_first = gtab_space_auto_first;
 
-
-  if (th.keybits==0)
-    th.keybits = 6;
-
-  inp->keybits = th.keybits;
+  inp->last_k_bitn = (((cur_inmd->key64 ? 64:32) / inp->keybits) - 1) * inp->keybits;
   inp->kmask = (1 << th.keybits) - 1;
 
+
 #if 0
   for(i='A'; i < 127; i++)
     printf("%d] %c %d\n", i, i, inp->keymap[i]);
 #endif
 #if 0
-  for(i=0; i < 100; i++) {
+  for(i=0; i < Min(100,th.DefC) ; i++) {
     u_char *ch = tblch(i);
-    dbg("%d] %c%c%c\n", i, ch[0], ch[1], ch[2]);
+    dbg("%d] %x %c%c%c\n", i, *((int *)inp->tbl[i].key), ch[0], ch[1], ch[2]);
   }
 #endif
 }
@@ -657,11 +681,18 @@ static void putstr_inp(u_char *p)
 
   char_play(p);
 
+  int to_tsin = (cur_inmd->flag & FLAG_GTAB_SYM_KBM) && default_input_method==6;
+
   if (utf8_str_N(p) > 1  || p[0] < 128) {
     if (gtab_disp_key_codes && !gtab_hide_row2 || wild_mode)
       lookup_gtabn(p, NULL);
-
-    send_text(p);
+#if USE_TSIN
+    if (to_tsin) {
+      add_to_tsin_buf_str(p);
+    }
+    else
+#endif
+      send_text(p);
   }
   else {
     if (same_pho_query_state == SAME_PHO_QUERY_gtab_input) {
@@ -676,7 +707,10 @@ static void putstr_inp(u_char *p)
     if (gtab_disp_key_codes && !gtab_hide_row2 || wild_mode)
       lookup_gtab(p);
 
-    sendkey_b5(p);
+    if (to_tsin)
+      add_to_tsin_buf_str(p);
+    else
+      sendkey_b5(p);
 
     if (gtab_auto_select_by_phrase && !(_gtab_space_auto_first & GTAB_space_auto_first_any)) {
       if (part_matched_len < strlen(match_phrase) &&
@@ -717,6 +751,13 @@ static void putstr_inp(u_char *p)
 
   ClrIn();
   ClrSelArea();
+
+  if ((cur_inmd->flag & FLAG_GTAB_SYM_KBM)) {
+    extern int win_kbm_inited, b_show_win_kbm;
+    init_in_method(default_input_method);
+    if (win_kbm_inited && !b_show_win_kbm)
+      hide_win_kbm();
+  }
 }
 
 
@@ -769,6 +810,15 @@ static u_int vmask[]=
  (0x3f<<24)|(0x3f<<18)|(0x3f<<12)|(0x3f<<6)|0x3f
 };
 
+
+static u_int vmask_7[]=
+{ 0,
+ (0x7f<<21),
+ (0x7f<<21)|(0x7f<<14),
+ (0x7f<<21)|(0x7f<<14)|(0x7f<<7),
+ (0x7f<<21)|(0x7f<<14)|(0x7f<<7)|0x7f,
+};
+
 #define KKK ((u_int64_t)0x3f)
 
 
@@ -786,6 +836,23 @@ static u_int64_t vmask64[]=
   (KKK<<54)|(KKK<<48)|(KKK<<42)|(KKK<<36)|(KKK<<30)|(KKK<<24)|(KKK<<18)|(KKK<<12)|(KKK<<6)|KKK
 };
 
+
+#define KKK7 ((u_int64_t)0x7f)
+
+static u_int64_t vmask64_7[]=
+{ 0,
+ (KKK7<<56),
+ (KKK7<<56)|(KKK7<<49),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35)|(KKK7<<28),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35)|(KKK7<<28)|(KKK7<<21),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35)|(KKK7<<28)|(KKK7<<21)|(KKK7<<14),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35)|(KKK7<<28)|(KKK7<<21)|(KKK7<<14)|(KKK7<<7),
+ (KKK7<<56)|(KKK7<<49)|(KKK7<<42)|(KKK7<<35)|(KKK7<<28)|(KKK7<<21)|(KKK7<<14)|(KKK7<<7)|KKK7,
+};
+
+
 #define KEY_N (cur_inmd->max_keyN)
 
 static gboolean load_seltab(int tblidx, int seltabidx)
@@ -819,7 +886,7 @@ gboolean cmp_inmd_idx(regex_t *reg, int idx)
 
   int i;
   for(i=0; i < KEY_N; i++) {
-    char c = (kk >> (LAST_K_bitN - i*6)) & cur_inmd->kmask;
+    char c = (kk >> (LAST_K_bitN - i*cur_inmd->keybits)) & cur_inmd->kmask;
     if (!c)
       break;
     ts[tsN++] = c + '0';
@@ -854,23 +921,37 @@ static void page_no_str(char tstr[])
   }
 }
 
-char *add_backslash(char *s, char out[])
+char *htmlspecialchars(char *s, char out[])
 {
+  struct {
+    char c;
+    char *str;
+  } chs[]= {{'>',"gt"}, {'<',"lt"}, {'&',"amp"}};
+  int chsN=sizeof(chs)/sizeof(chs[0]);
+
   int outn=0;
-
-  for(;*s; s++) {
-
-    if (*s=='<') {
-      char t[]="&lt;";
-      int len=strlen(t);
-      memcpy(out+outn, t, len);
+  while (*s) {
+    int sz = utf8_sz(s);
+    int i;
+    for(i=0; i<chsN; i++)
+      if (chs[i].c==*s)
+        break;
+    if (i==chsN) {
+      memcpy(&out[outn],s, sz);
+      outn+=sz;
+      s+=sz;
+    }
+    else {
+      out[outn++]='&';
+      int len=strlen(chs[i].str);
+      memcpy(&out[outn], chs[i].str, len);
       outn+=len;
-    } else
-      out[outn++]=*s;
+      out[outn++]=';';
+      s++;
+    }
   }
 
   out[outn]=0;
-
   return out;
 }
 
@@ -893,9 +974,8 @@ static void disp_selection(gboolean phrase_selected)
   char uu[MAX_CIN_PHR];
 
   int ofs;
-
   if (!wild_mode && exa_match && (_gtab_space_auto_first & GTAB_space_auto_first_any)) {
-    strcat(tt, add_backslash(seltab[0], uu));
+    strcat(tt, htmlspecialchars(seltab[0], uu));
     if (gtab_vertical_select)
       strcat(tt, "\n");
     else
@@ -909,9 +989,14 @@ static void disp_selection(gboolean phrase_selected)
   for(i=ofs; i< cur_inmd->M_DUP_SEL + ofs; i++) {
     if (seltab[i][0]) {
       char selback[MAX_CIN_PHR+16];
-      add_backslash(seltab[i], selback);
+      htmlspecialchars(seltab[i], selback);
+
+      utf8cpy(uu, &cur_inmd->selkey[i - ofs]);
+      char vvv[16];
+      char www[512];
+      sprintf(www, "<span foreground=\"%s\">%s</span>", gcin_sel_key_color, htmlspecialchars(uu, vvv));
+      strcat(tt, www);
 
-      b1_cat(tt, cur_inmd->selkey[i - ofs]);
       if (gtab_vertical_select)
         strcat(tt, ". ");
 
@@ -989,11 +1074,11 @@ void wildcard()
   for(i=0; i < KEY_N; i++) {
     if (!inch[i])
       break;
-    if (inch[i] == WILD_STAR) {
+    if (inch[i] == cur_inmd->WILD_STAR) {
       regstr[regstrN++]='.';
       regstr[regstrN++]='*';
     } else
-    if (inch[i] == WILD_QUES) {
+    if (inch[i] == cur_inmd->WILD_QUES) {
       regstr[regstrN++]='.';
     } else {
       char c = inch[i] + '0';         // start from '0'
@@ -1082,7 +1167,7 @@ static gboolean has_wild_card()
   int i;
 
   for(i=0; i < cur_inmd->MaxPress; i++)
-    if (inch[i]>60) {
+    if (inch[i]>= cur_inmd->WILD_QUES) {
       return TRUE;
     }
 
@@ -1147,6 +1232,20 @@ gboolean feedkey_gtab(KeySym key, int kbstate)
   if (same_pho_query_state == SAME_PHO_QUERY_pho_select)
     return feedkey_pho(key, 0);
 
+
+  if (gtab_capslock_in_eng && (kbstate&LockMask)) {
+    if (key < 0x20 || key>=0x7f)
+      return 0;
+
+    if (gcin_capslock_lower) {
+      case_inverse(&key, shift_m);
+      send_ascii(key);
+      return 1;
+    } else
+      return 0;
+  }
+
+
   int lcase = tolower(key);
   int ucase = toupper(key);
   if (key < 127 && cur_inmd->keymap[key]) {
@@ -1155,15 +1254,6 @@ gboolean feedkey_gtab(KeySym key, int kbstate)
      if (cur_inmd->keymap[lcase] != cur_inmd->keymap[ucase])
        goto next;
 
-     if (gtab_capslock_in_eng && (kbstate&LockMask)) {
-       if (gcin_capslock_lower) {
-         case_inverse(&key, shift_m);
-         send_ascii(key);
-         return 1;
-       }
-
-       return 0;
-     }
   }
 
 
@@ -1274,6 +1364,8 @@ next_page:
 
       has_wild = has_wild_card();
 
+//      dbg("wild_mode:%d more_pg:%d ci:%d  has_wild:%d\n", wild_mode, more_pg, ci, has_wild);
+
       if (wild_mode) {
         // request from tetralet
         if (!wild_page && total_matchN < cur_inmd->M_DUP_SEL) {
@@ -1292,11 +1384,12 @@ next_page:
         goto next_page;
       } else
       if (ci==0) {
+#if 0
         if (last_full) {
           last_full=0;
-          return 1;
+//          return 1;
         }
-
+#endif
         if (current_CS->b_half_full_char)
           return full_char_proc(key);
 
@@ -1337,8 +1430,12 @@ direct_select:
       if (!gtab_que_wild_card)
         return 0;
     case '*':
+      inkey=cur_inmd->keymap[key];
+      if ((inkey && (inkey!=cur_inmd->WILD_STAR && inkey!=cur_inmd->WILD_QUES)) || ptr_selkey(key)) {
+//        dbg("%d %d\n", inkey, cur_inmd->WILD_STAR);
+        goto next;
+      }
       if (ci< cur_inmd->MaxPress) {
-        inkey=cur_inmd->keymap[key];
         inch[ci++]=inkey;
         DispInArea();
 
@@ -1425,10 +1522,6 @@ next:
         putstr_inp(seltab[sel1st_i]);  /* select 1st */
       }
 
-#if 0
-      if (wild_mode)
-        goto XXXX;
-#endif
       if (key > 0x7f) {
         return 0;
       }
@@ -1487,8 +1580,8 @@ next:
 
 
       if (inkey) {
-        for(i=0; i < MAX_TAB_KEY_NUM64; i++)
-          if (inch[i]>60) {
+        for(i=0; i < MAX_TAB_KEY_NUM64_6; i++)
+          if (inch[i]>=cur_inmd->WILD_QUES) {
             DispInArea();
             if (ci==cur_inmd->MaxPress) {
               wild_mode=1;
@@ -1527,10 +1620,10 @@ next:
   static u_int64_t val; // needs static
   val=0;
 
+
   for(i=0; i < Max_tab_key_num; i++)
     val|= (u_int64_t)inch[i] << (KeyBits * (Max_tab_key_num - 1 - i));
 
-//  dbg("--------- %d val %llx\n", Max_tab_key_num, val);
 #if 1
   if (last_idx)
     S1=last_idx;
@@ -1538,8 +1631,14 @@ next:
 #endif
     S1=cur_inmd->idx1[inch[0]];
 
+//  dbg("--------- ch:%d %d val %llx  S1:%d\n", inch[0], Max_tab_key_num, val, S1);
+
   int oE1=cur_inmd->idx1[inch[0]+1];
-  u_int64_t vmaskci = cur_inmd->key64 ? vmask64[ci]:vmask[ci];
+  u_int64_t vmaskci;
+  if (cur_inmd->keybits==6)
+    vmaskci = cur_inmd->key64 ? vmask64[ci]:vmask[ci];
+  else
+    vmaskci = cur_inmd->key64 ? vmask64_7[ci]:vmask_7[ci];
 
   while ((CONVT2(cur_inmd, S1) & vmaskci) != val &&
           CONVT2(cur_inmd, S1) < val &&  S1<oE1)
@@ -1548,13 +1647,15 @@ next:
   pg_idx=last_idx=S1;
 
 #if 0
-  dbg("ci:%d  %d\n", ci, ((CONVT2(cur_inmd, S1) & vmaskci)!=val));
+  dbg("MaxPress:%d vmaskci:%x ci:%d  !=%d\n", cur_inmd->MaxPress, vmaskci, ci,
+  ((CONVT2(cur_inmd, S1) & vmaskci)!=val));
 #endif
 
   if ((CONVT2(cur_inmd, S1) & vmaskci)!=val || (wild_mode && defselN) ||
                   ((ci==cur_inmd->MaxPress||spc_pressed) && defselN &&
       (pselkey && ( pendkey || spc_pressed)) ) ) {
 YYYY:
+
     if ((pselkey || wild_mode) && defselN) {
       int vv = pselkey - cur_inmd->selkey;
 
@@ -1613,6 +1714,7 @@ refill:
       more_pg = 1;
   }
 
+
   if (ci < cur_inmd->MaxPress && !spc_pressed && !pendkey && !more_pg) {
     j = S1;
     exa_match=0;
