@@ -1,5 +1,5 @@
 /*
-	Copyright (C) 1995	Edward Der-Hua Liu, Hsin-Chu, Taiwan
+	Copyright (C) 1995-2008	Edward Der-Hua Liu, Hsin-Chu, Taiwan
 */
 
 #include <stdio.h>
@@ -64,8 +64,8 @@ static int qcmp_usecount(const void *a, const void *b)
   u_short ka,kb;
   usecount_t usecounta, usecountb;
 
-  lena=*(pa++); usecounta = *((usecount_t *)pa); pa+= sizeof(usecount_t);
-  lenb=*(pb++); usecountb = *((usecount_t *)pb); pb+= sizeof(usecount_t);
+  lena=*(pa++); memcpy(&usecounta, pa, sizeof(usecount_t)); pa+= sizeof(usecount_t);
+  lenb=*(pb++); memcpy(&usecountb, pb, sizeof(usecount_t)); pb+= sizeof(usecount_t);
   len=Min(lena,lenb);
 
   for(i=0;i<len;i++) {
@@ -169,7 +169,10 @@ int main(int argc, char **argv)
       kk=0;
 
       while (s[i]!=' ' && i<len) {
-        kk |= lookup(&s[i]);
+        if (kk==(BACK_QUOTE_NO << 9))
+          kk|=s[i];
+        else
+          kk |= lookup(&s[i]);
 
         i+=utf8_sz(&s[i]);
       }
