@@ -1,5 +1,5 @@
 /*
-	Copyright (C) 2004	Edward Liu, Taiwan
+	Copyright (C) 2004-2008	Edward Der-Hua Liu, Hsin-Chu, Taiwan
 */
 #include <string.h>
 
@@ -16,6 +16,7 @@ extern char *pho_chars[];
 
 extern int ityp3_pho;
 extern u_char typ_pho[];
+gboolean typ_pho_empty();
 extern char inph[];
 
 extern u_short hash_pho[];
@@ -29,12 +30,13 @@ int c_idx;
 extern int c_len;
 int ph_sta=-1, ph_sta_last=-1;  // phrase start
 static int sel_pho;
-static gboolean eng_ph=TRUE;  // english(FALSE) <-> pho(juyin, TRUE)
+gboolean eng_ph=TRUE;  // english(FALSE) <-> pho(juyin, TRUE)
 static int save_frm, save_to;
 static int current_page;
 static int startf;
 static gboolean full_match;
 static gboolean tsin_half_full;
+static gboolean tsin_buffer_editing = 0;
 
 typedef struct {
   phokey_t phokey[MAX_PHRASE_LEN];
@@ -243,13 +245,10 @@ static void disp_in_area_pho_tsin()
 void clear_chars_all();
 
 
-static void clear_disp_ph_sta();
 static void clear_match()
 {
   ph_sta=-1;
-  clear_disp_ph_sta();
-//  bzero(psta, sizeof(psta));
-//  dbg("clear_match\n");
+  clear_tsin_line();
 }
 
 static void clr_ch_buf()
@@ -270,7 +269,7 @@ static void clear_ch_buf_sel_area()
   full_match = FALSE;
   clr_ch_buf();
   drawcursor();
-  clear_disp_ph_sta();
+  clear_tsin_line();
 }
 
 static void close_selection_win();
@@ -280,6 +279,7 @@ static void clear_tsin_buffer()
   clear_ch_buf_sel_area();
   close_selection_win();
   pre_selN = 0;
+  tsin_buffer_editing = 0; //buffer editing is finished
 }
 
 void clr_in_area_pho_tsin();
@@ -325,12 +325,12 @@ void disp_tsin_eng_pho(int eng_pho);
 
 void show_stat()
 {
+  load_tray_icon();
   disp_tsin_eng_pho(eng_ph);
 }
 
 void load_tsin_db();
 
-
 #if 0
 void nputs(u_char *s, u_char len)
 {
@@ -383,28 +383,24 @@ static void dump_tsidx_all()
 void load_tab_pho_file();
 void show_win0();
 
-void init_tab_pp(int usenow)
+void init_tab_pp(gboolean init)
 {
   if (!ch_pho)
     load_tab_pho_file();
 
-  if (phcount && gwin0) {
-disp_prom:
-    show_stat();
-    clear_ch_buf_sel_area();
-    if (!gcin_pop_up_win)
-      show_win0();
-
-    return;
+  if (!phcount) {
+    load_tsin_db();
+    if (init)
+      clr_ch_buf();
+//    show_win0();
   }
 
-  load_tsin_db();
+  show_stat();
+  if (init)
+    clear_ch_buf_sel_area();
 
-  clr_ch_buf();
-  show_win0();
-
-//  dump_tsidx_all();
-  goto disp_prom;
+  if (!gcin_pop_up_win)
+    show_win0();
 }
 
 gboolean save_phrase_to_db2(CHPHO *chph, int len);
@@ -556,6 +552,9 @@ static void get_sel_phrase()
 
   mlen=c_len-c_idx;
 
+  if (!mlen)
+    return;
+
   if (mlen > MAX_PHRASE_LEN)
     mlen=MAX_PHRASE_LEN;
 
@@ -874,12 +873,15 @@ void tsin_set_eng_ch(int nmod)
   drawcursor();
 
   show_button_pho(eng_ph);
-
+  load_tray_icon();
+#if 0
   show_win0();
+#endif
 }
 
 void tsin_toggle_eng_ch()
 {
+  compact_win0_x();
   tsin_set_eng_ch(!eng_ph);
 }
 
@@ -904,28 +906,25 @@ static void hide_pre_sel()
 }
 
 
-void clear_tsin_line();
-
-static void clear_disp_ph_sta()
-{
-  clear_tsin_line();
-}
 
 void draw_underline(int index);
 
+static void draw_ul(start, stop)
+{
+  int i;
+  for(i=start; i < stop; i++)
+    draw_underline(i);
+}
+
 void disp_ph_sta_idx(int idx)
 {
 //  dbg("ph_sta:%d\n", ph_sta);
-  clear_disp_ph_sta();
+  clear_tsin_line();
 
   if (ph_sta < 0)
     return;
 
-  int i;
-
-  for(i=idx; i < c_idx; i++) {
-    draw_underline(i);
-  }
+  draw_ul(idx, c_idx);
 }
 
 void disp_ph_sta()
@@ -1209,15 +1208,107 @@ static KeySym keypad_proc(KeySym xkey)
       case XK_KP_Divide:
         xkey = '/';
         break;
+      case XK_KP_Decimal:
+        xkey = '.';
+        break;
+      default:
+        return 0;
     }
   }
 
   return xkey;
 }
 
+static int cursor_left()
+{
+  close_selection_win();
+  if (c_idx) {
+    clrcursor();
+    c_idx--;
+    drawcursor();
+    return 1;
+  }
+  // Thanks to PCMan.bbs@bbs.sayya.org for the suggestion
+  return c_len;
+}
+static int cursor_right()
+{
+  close_selection_win();
+  if (c_idx < c_len) {
+    clrcursor();
+    c_idx++;
+    drawcursor();
+    return 1;
+  }
+
+  // Thanks to PCMan.bbs@bbs.sayya.org for the suggestion
+  return c_len;
+}
+
+static int cursor_delete()
+{
+  if (c_idx == c_len)
+    return 0;
+  close_selection_win();
+  clear_tsin_line();
+  ityp3_pho=0;
+  pre_selN = 0;
+
+  int j;
+  for(j=3;j>=0;j--)
+    if (typ_pho[j]) {
+      typ_pho[j]=0;
+      disp_in_area_pho_tsin();
+      return 1;
+    }
+
+  clrcursor();
+  int k;
+  int pst=k=chpho[c_idx].psta;
+
+  for(k=c_idx;k<c_len;k++) {
+    chpho[k] = chpho[k+1];
+    chpho[k].psta=chpho[k+1].psta-1;
+  }
+
+  c_len--;
+  hide_char(c_len);
+  init_chpho_i(c_len);
+
+  prbuf();
+
+  compact_win0_x();
+
+  if (!c_idx)
+    clear_match();
+  else {
+    k=c_idx-1;
+    pst=chpho[k].psta;
+
+    while (k>0 && chpho[k].psta==pst)
+      k--;
+
+    if (chpho[k].psta!=pst)
+      k++;
+
+    int match_len= c_idx - k;
+    if (!(match_len=scanphr(k, match_len, FALSE)))
+      ph_sta=-1;
+    else
+      ph_sta=k;
+
+    if (ph_sta < 0 || c_idx - ph_sta < 2)
+      pre_selN = 0;
+  }
+
+  if (!c_len && gcin_pop_up_win)
+    hide_win0();
+
+  disp_ph_sta();
+  return 1;
+}
 
 void case_inverse();
-
 void pho_play(phokey_t key);
 
 int feedkey_pp(KeySym xkey, int kbstate)
@@ -1237,16 +1328,23 @@ int feedkey_pp(KeySym xkey, int kbstate)
      return 0;
    }
 
+   if (xkey==XK_Shift_L||xkey==XK_Shift_R)
+      key_press_time = current_time();
+
+   if (!eng_ph && !c_len && gcin_pop_up_win && xkey!=XK_Caps_Lock) {
+     hide_win0();
+     return 0;
+   }
+
    int o_sel_pho = sel_pho;
    close_win_pho_near();
 
    switch (xkey) {
      case XK_Escape:
        tsin_reset_in_pho0();
-       if (!typ_pho[0] && !typ_pho[1] && !typ_pho[2] && !typ_pho[3]) {
+       if (typ_pho_empty()) {
          if (!c_len)
            return 0;
-
          if (!o_sel_pho && tsin_tab_phrase_end)
            goto tab_phrase_end;
        }
@@ -1255,12 +1353,21 @@ int feedkey_pp(KeySym xkey, int kbstate)
      case XK_Return:
      case XK_KP_Enter:
         if (shift_m) {
+          if (!c_len)
+            return 0;
           save_frm=c_idx;
           save_to=c_len-1;
+          draw_ul(c_idx, c_len);
           save_phrase();
           return 1;
-        } else
-          return flush_tsin_buffer();
+        } else {
+          if (c_len)
+            flush_tsin_buffer();
+          else
+          if (typ_pho_empty())
+            return 0;
+          return 1;
+        }
      case XK_Home:
         close_selection_win();
         if (!c_len)
@@ -1278,31 +1385,9 @@ int feedkey_pp(KeySym xkey, int kbstate)
         drawcursor();
         return 1;
      case XK_Left:
-        close_selection_win();
-        if (c_idx) {
-          clrcursor();
-          c_idx--;
-          drawcursor();
-          return 1;
-        }
-        // Thanks to PCMan.bbs@bbs.sayya.org for the suggestion
-        if (c_len)
-          return 1;
-        return 0;
+        return cursor_left();
      case XK_Right:
-        close_selection_win();
-        if (c_idx < c_len) {
-          clrcursor();
-          c_idx++;
-          drawcursor();
-          return 1;
-        }
-
-        // Thanks to PCMan.bbs@bbs.sayya.org for the suggestion
-        if (c_len)
-          return 1;
-
-        return 0;
+        return cursor_right();
      case XK_Caps_Lock:
         if (tsin_chinese_english_toggle_key == TSIN_CHINESE_ENGLISH_TOGGLE_KEY_CapsLock) {
           close_selection_win();
@@ -1332,70 +1417,11 @@ tab_phrase_end:
           }
         }
         return 0;
-     case XK_Shift_L:
-     case XK_Shift_R:
-        key_press_time = current_time();
-        return 1;
      case XK_Delete:
-        if (c_idx == c_len)
-          return 0;
-
-        close_selection_win();
-        clear_disp_ph_sta();
-        ityp3_pho=0;
-        pre_selN = 0;
-
-        for(j=3;j>=0;j--)
-          if (typ_pho[j]) {
-            typ_pho[j]=0;
-            disp_in_area_pho_tsin();
-            return 1;
-          }
-
-        clrcursor();
-        pst=k=chpho[c_idx].psta;
-
-        for(k=c_idx;k<c_len;k++) {
-          chpho[k] = chpho[k+1];
-          chpho[k].psta=chpho[k+1].psta-1;
-        }
-
-        c_len--;
-        hide_char(c_len);
-        init_chpho_i(c_len);
-
-        prbuf();
-
-        compact_win0_x();
-
-        if (!c_idx) {
-          clear_match();
-        }
-        else {
-          k=c_idx-1;
-          pst=chpho[k].psta;
-
-          while (k>0 && chpho[k].psta==pst)
-            k--;
-
-          if (chpho[k].psta!=pst)
-            k++;
-
-          match_len= c_idx - k;
-          if (!(match_len=scanphr(k, match_len, FALSE)))
-            ph_sta=-1;
-          else
-            ph_sta=k;
-
-//          if (ph_sta < 0 || c_idx - ph_sta < 2)
-            pre_selN = 0;
-        }
-
-        disp_ph_sta();
-        return 1;
+        return cursor_delete();
      case XK_BackSpace:
         close_selection_win();
-        clear_disp_ph_sta();
+        clear_tsin_line();
         ityp3_pho=0;
         pre_selN = 0;
 
@@ -1408,6 +1434,9 @@ tab_phrase_end:
             if (pre_selN > 1 && scanphr(ph_sta, c_idx - ph_sta, TRUE)) {
               disp_pre_sel_page();
             }
+
+            if (!c_len && gcin_pop_up_win && !j)
+              hide_win0();
             return 1;
           }
 
@@ -1431,8 +1460,7 @@ tab_phrase_end:
 
         if (!c_idx) {
           clear_match();
-        }
-        else {
+        } else {
           k=c_idx-1;
           pst=chpho[k].psta;
 
@@ -1453,6 +1481,10 @@ tab_phrase_end:
         }
 
         disp_ph_sta();
+
+        if (!c_len && gcin_pop_up_win)
+          hide_win0();
+
         return 1;
      case XK_Up:
        if (!sel_pho) {
@@ -1536,24 +1568,39 @@ other_keys:
        if ((kbstate & ControlMask)) {
          if (xkey==XK_u) {
            clear_tsin_buffer();
+           if (gcin_pop_up_win)
+             hide_win0();
+           return 1;
+         } else if (tsin_buffer_editing_mode && xkey == XK_e) { //ctrl+e only works when user enabled tsin_buffer_editing_mode
+           //toggler
+           tsin_buffer_editing ^= 1;
+           return 1;
+         } else if (xkey>=XK_1 && xkey<=XK_3) {
            return 1;
          } else
-         if (xkey>=XK_1 && xkey<=XK_3) {
-           return 1;
-         } else {
            return 0;
-         }
        }
 
-       char *pp;
-
        char xkey_lcase = xkey;
-       if ('A' <= xkey && xkey <= 'Z')
-          xkey_lcase = tolower(xkey);
+       if ('A' <= xkey && xkey <= 'Z') {
+         xkey_lcase = tolower(xkey);
+       }
+
+       if (tsin_buffer_editing) {
+         if (xkey_lcase=='h')
+           return cursor_left();
+         else
+         if (xkey_lcase=='l')
+           return cursor_right();
+         else
+         if (xkey_lcase=='x')
+           return cursor_delete();
+       }
 
        if (tsin_space_opt == TSIN_SPACE_OPT_INPUT)
          xkey_lcase = keypad_proc(xkey);
 
+       char *pp;
        if ((pp=strchr(phkbm.selkey,xkey_lcase)) && sel_pho) {
          int c=pp-phkbm.selkey;
          char *sel_text;
@@ -1561,28 +1608,19 @@ other_keys:
 
          if (len > 1) {
            int cpsta = chpho[c_idx].psta;
-           if (cpsta >= 0) {
-#if 0
-             chpho[cpsta].flag |= FLAG_CHPHO_PHRASE_VOID;
-#endif
+           if (cpsta >= 0)
              set_chpho_ch(&chpho[c_idx], sel_text, len);
-           } else
+           else
              set_chpho_ch2(&chpho[c_idx], sel_text, len);
 
            chpho[c_idx].flag &= ~FLAG_CHPHO_PHRASE_VOID;
-#if 0
-           set_phrase_link(c_idx, len);
-#endif
            set_fixed(c_idx, len);
 
            call_tsin_parse();
 
            if (c_idx + len == c_len) {
              ph_sta = -1;
-
-             for(i=c_idx; i < c_len; i++) {
-                draw_underline(i);
-             }
+             draw_ul(c_idx, c_len);
            }
          } else
          if (len == 1) { // single chinese char
@@ -1598,9 +1636,7 @@ other_keys:
            }
 
            set_fixed(i, 1);
-#if 1
            call_tsin_parse();
-#endif
          }
 
          if (len) {
@@ -1622,15 +1658,14 @@ other_keys:
        sel_pho=current_page=0;
    }
 
-   if (!eng_ph || shift_m || (xkey <= XK_KP_9 && xkey >= XK_KP_0) ||
-        xkey == XK_KP_Subtract || xkey == XK_KP_Add || xkey == XK_KP_Multiply ||
-        xkey == XK_KP_Divide
-       ) {
-
-       xkey = keypad_proc(xkey);
+   KeySym key_pad = keypad_proc(xkey);
+   if (!eng_ph || typ_pho[0]!=BACK_QUOTE_NO && (shift_m || key_pad || !phkbm.phokbm[xkey][0].num)) {
+       if (key_pad)
+         xkey = key_pad;
 asc_char:
         if (shift_m) {
           if (pre_sel_handler(xkey)) {
+            call_tsin_parse();
             return 1;
           }
 
@@ -1693,11 +1728,12 @@ asc_char:
      }
 
      // for hsu & et26
-     if (strchr(hsu_punc, xkey) && !phkbm.phokbm[xkey][0].num)
+     if (strchr(hsu_punc, xkey) && !phkbm.phokbm[xkey][0].num && typ_pho[0]!=BACK_QUOTE_NO)
        return pre_punctuation_hsu(xkey);
 
-     if (xkey >= 'A' && xkey <='Z')
+     if (xkey >= 'A' && xkey <='Z' && typ_pho[0]!=BACK_QUOTE_NO)
        xkey+=0x20;
+//     printf("bbbb %c\n", xkey);
 
      inph_typ_pho(xkey);
 
@@ -1732,18 +1768,23 @@ llll2:
      pho_play(key);
 
      int vv=hash_pho[typ_pho[0]];
+
      phokey_t ttt=0xffff;
      while (vv<idxnum_pho) {
        ttt=idx_pho[vv].key;
-       if (!typ_pho[0]) ttt &= ~(31<<9);
-       if (!typ_pho[1]) ttt &= ~(3<<7);
-       if (!typ_pho[2]) ttt &= ~(15<<3);
-       if (!typ_pho[3]) ttt &= ~(7);
+       if (typ_pho[0]!=BACK_QUOTE_NO) {
+         if (!typ_pho[0]) ttt &= ~(31<<9);
+         if (!typ_pho[1]) ttt &= ~(3<<7);
+         if (!typ_pho[2]) ttt &= ~(15<<3);
+         if (!typ_pho[3]) ttt &= ~(7);
+       }
        if (ttt>=key) break;
        else
        vv++;
      }
-
+#if 0
+     printf("aaaa vv:%d  idxnum_pho:%d   ttt:%x key:%x\n",vv, idxnum_pho, ttt, key);
+#endif
      if (ttt > key || (ityp3_pho && idx_pho[vv].key!=key) ) {
        while (jj<4) {
          while(kk<3)
@@ -1767,11 +1808,20 @@ llll2:
        return 1;
      }
 
-     if (key==0 || !ityp3_pho)
+     if (typ_pho[0]==BACK_QUOTE_NO && typ_pho[1])
+       ityp3_pho = 1;
+
+     if (key==0 || !ityp3_pho) {
        return 1;
+     }
 
      ii=idx_pho[vv].start;
      start_idx=ii;
+#if 0
+     printf("%x %x %d vv:%d idxnum_pho:%d-->", ttt, key, start_idx, vv, idxnum_pho);
+     utf8_putchar(ch_pho[start_idx].ch);
+     puts("<---");
+#endif
    } /* pho */
 
    put_b5_char(ch_pho[start_idx].ch, key);
@@ -1877,11 +1927,11 @@ restart:
 
        if (j < mdist)
          continue;
-
+#if 0
        ch_pho_cpy(&chpho[ph_sta], pre_sel[i].str, pre_sel[i].phokey, mdist);
        if (chpho[ph_sta].psta < 0)
          set_chpho_ch2(&chpho[ph_sta], pre_sel[i].str, mdist);
-
+#endif
 
        int j;
        for(j=0;j < mdist; j++) {
