@@ -10,13 +10,13 @@ void p_err(char *fmt,...)
   vfprintf(stderr, fmt, args);
   va_end(args);
   fprintf(stderr,"\n");
-#if 0
+#if DEBUG
+  abort();
+#else
   if (getenv("GCIN_ERR_COREDUMP"))
     abort();
 
   exit(-1);
-#else
-  abort();
 #endif
 }
 
