@@ -16,7 +16,7 @@ void create_inmd_switch()
   menu = gtk_menu_new ();
 
   int i;
-  for(i=0; i < MAX_GTAB_NUM_KEY; i++) {
+  for(i=1; i <= MAX_GTAB_NUM_KEY; i++) {
     if (!inmd[i].cname || !inmd[i].cname[0])
       continue;
 
