@@ -68,6 +68,8 @@ static void create_char(int index)
 
   GdkColor fg;
   gdk_color_parse(gcin_win_color_fg, &fg);
+  GdkColor color_bg;
+  gdk_color_parse(tsin_phrase_line_color, &color_bg);
 
   for(i=index; i<=index+1 && i < MAX_PH_BF_EXT; i++) {
     if (chars[i].vbox)
@@ -84,8 +86,6 @@ static void create_char(int index)
 
     chars[i].label = label;
     GtkWidget *separator =  gtk_drawing_area_new();
-    GdkColor color_bg;
-    gdk_color_parse(tsin_phrase_line_color, &color_bg);
     gtk_widget_modify_bg(separator, GTK_STATE_NORMAL, &color_bg);
     gtk_widget_set_size_request(separator, 8, 2);
     gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
@@ -105,12 +105,12 @@ static void change_tsin_line_color()
 
   GdkColor fg;
   gdk_color_parse(gcin_win_color_fg, &fg);
+  GdkColor color_bg;
+  gdk_color_parse(tsin_phrase_line_color, &color_bg);
 
   for(i=0; i < MAX_PH_BF_EXT; i++) {
     if (!chars[i].line)
       continue;
-    GdkColor color_bg;
-    gdk_color_parse(tsin_phrase_line_color, &color_bg);
     gtk_widget_modify_bg(chars[i].line, GTK_STATE_NORMAL, &color_bg);
     gtk_widget_modify_fg(chars[i].label, GTK_STATE_NORMAL, gcin_win_color_use ? &fg:NULL);
   }
@@ -127,16 +127,15 @@ void disp_char(int index, char *ch)
 {
   char tt[CH_SZ+1];
 
-//  dbg("disp_char %d %c%c\n", index, ch[0], ch[1]);
+//  dbg("disp_char %d %c%c%c\n", index, ch[0], ch[1], ch[2]);
   create_char(index);
   GtkWidget *label = chars[index].label;
 
-  int u8len = u8cpy(tt, ch);
+  utf8cpy(tt, ch);
 
   if (ch[0]==' ' && ch[1]==' ')
       set_label_space(label);
   else {
-    tt[u8len] = 0;
     gtk_label_set_text(GTK_LABEL(label), tt);
   }
 
@@ -202,9 +201,6 @@ void clr_tsin_cursor(int index)
 }
 
 
-
-
-
 void disp_pho_sub();
 
 
@@ -278,7 +274,7 @@ void move_win_char_index(GtkWidget *win1, int index)
   gtk_window_move(GTK_WINDOW(win1), x, y);
 }
 
-#define MIN_X_SIZE 16
+#define MIN_X_SIZE 32
 
 static int best_win_x, best_win_y;
 
@@ -316,6 +312,7 @@ void compact_win0()
 }
 
 gboolean tsin_has_input();
+GtkWidget *gwin_sym;
 
 void move_win0(int x, int y)
 {
@@ -334,15 +331,11 @@ void move_win0(int x, int y)
   if (y < 0)
     y = 0;
 
-
   gtk_window_move(GTK_WINDOW(gwin0), x, y);
   win_x = x;
   win_y = y;
 
-  if (gcin_pop_up_win && !tsin_has_input())
-    return;
-
-  show_win_sym();
+  move_win_sym();
 }
 
 GtkWidget *gwin1;
@@ -371,13 +364,12 @@ void clear_tsin_line()
 
 void exec_gcin_setup();
 
-
 static void mouse_button_callback( GtkWidget *widget,GdkEventButton *event, gpointer data)
 {
 //  dbg("mouse_button_callback %d\n", event->button);
   switch (event->button) {
     case 1:
-      create_win_sym();
+      toggle_win_sym();
       break;
     case 2:
       inmd_switch_popup_handler(widget, (GdkEvent *)event);
@@ -392,6 +384,7 @@ static void mouse_button_callback( GtkWidget *widget,GdkEventButton *event, gpoi
 
 extern char file_pin_float[];
 
+#if 0
 static void set_currenet_IC_pin_image_pin()
 {
   if (!image_pin)
@@ -402,6 +395,7 @@ static void set_currenet_IC_pin_image_pin()
   else
     gtk_image_set_from_file(GTK_IMAGE(image_pin), file_pin_float);
 }
+#endif
 
 static void cb_clicked_fixed_pos()
 {
@@ -418,7 +412,7 @@ static void cb_clicked_fixed_pos()
     current_CS->fixed_x = win_x;  current_CS->fixed_y = win_y;
   }
 
-  set_currenet_IC_pin_image_pin();
+//  set_currenet_IC_pin_image_pin();
 }
 
 void tsin_toggle_eng_ch();
@@ -547,7 +541,7 @@ static void create_win0_gui()
   set_label_font_size(label_pho, gcin_font_size_tsin_pho_in);
   gtk_container_add (GTK_CONTAINER (button_pho), label_pho);
 
-
+#if 0
   if (!pho_simple_win) {
     GtkWidget *hbox_row2 = gtk_hbox_new (FALSE, 0);
   //  gtk_container_set_border_width (GTK_CONTAINER (hbox_row2), 0);
@@ -570,6 +564,7 @@ static void create_win0_gui()
     g_signal_connect (G_OBJECT (event_box_pin), "button_press_event",
         G_CALLBACK (cb_clicked_fixed_pos), (gpointer) NULL);
   }
+#endif
 
   clr_in_area_pho_tsin();
 
@@ -601,27 +596,26 @@ void get_win0_geom()
   get_win_size(gwin0, &win_xl, &win_yl);
 }
 
-gboolean tsin_has_input();
+gboolean tsin_has_input(), force_show;
 
 void show_win0()
 {
 //  dbg("show_win0\n");
   create_win0();
   create_win0_gui();
-  set_currenet_IC_pin_image_pin();
+//  set_currenet_IC_pin_image_pin();
 
-  if (gcin_pop_up_win && !tsin_has_input())
+  if (gcin_pop_up_win && !tsin_has_input() && !force_show)
     return;
 
   gtk_widget_show(gwin0);
 //  dbg("show_win0 b\n");
+
   show_win_sym();
-#if 1
   if (current_CS->b_raise_window) {
     gtk_window_present(gwin0);
     raise_tsin_selection_win();
   }
-#endif
 }
 
 void hide_selections_win();
